@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +26,14 @@
 #include "addspot.h"
 #include "changefreq.h"
 
+
+
 int callinput(void)
 {
+extern int itumult;
+extern int wazmult;
 extern int use_rxvt;
+extern int no_arrows;
 extern int isdupe;			// LZ3NY auto-b4 patch
 extern int contest;
 extern int dxped;
@@ -57,11 +62,11 @@ extern float freq;
 extern float mem;
 #ifdef HAVE_LIBHAMLIB
 extern freq_t outfreq;
-extern int trx_control;
-extern float bandfrequency[];
 #else
 extern int outfreq;
 #endif
+extern int trx_control;
+extern float bandfrequency[];
 extern SCREEN *mainscreen;
 extern int simulator;
 extern int simulator_mode;
@@ -74,6 +79,7 @@ extern int showscore_flag;
 extern int searchflg;
 extern int cqww ;
 extern char cqzone[];
+extern char ituzone[];
 extern int ctcomp;
 extern int nroflines;
 extern int bandmap_pos;
@@ -81,33 +87,40 @@ extern int allspots;
 extern int nob4;
 extern int weight;
 extern int k_tune;
+extern int tune_val;
 extern int k_pin14;
 extern int k_ptt;
+extern int noautocq;
+extern int keyerport;
+extern int miniterm;
+extern int rignumber;
 
 
-int  i, j, ii, t, x = 0, y=0, inchar,  xx, secs;
+int  i, j, ii, t, x = 0, y=0,  xx;
 char instring[2];
 char dupecall[17];
 char speedbuf[3] = "";
 char weightbuf[5];
 static int lastwindow;
-int fdaudioin, fdaudiodev, numbytes;
-char audiobuf[10];
-
 
 instring[1] = '\0';
 
+void send_bandswitch(int freq);
+
 if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
 else     attron(COLOR_PAIR(NORMCOLOR) );
 
 mvprintw(12, 29, "            ");
 printcall();
-	
-	for  (i= strlen(hiscall) ; i <= 10 ; i++)
+
+	for  (i= strlen(hiscall) ; i <= 13 ; i++)
 	{
          	time_update();
-         	
-		
+
+		if (trxmode == DIGIMODE && keyerport == MFJ1278_KEYER)
+			show_rtty();
+
+
 		if  (i == 0 || strlen(hiscall)  == 0)
 		{
 			nodelay(stdscr, TRUE);            /* main loop waiting for input */
@@ -116,11 +129,13 @@ printcall();
 
 				time_update();
 
+				if (trxmode == DIGIMODE && keyerport == MFJ1278_KEYER)
+					show_rtty();
 
 				x = onechar();
 
 
-				}
+			}
 		 	nodelay(stdscr, FALSE);
 
 
@@ -146,14 +161,16 @@ printcall();
 			}
 
 			if (x == '\n' && strlen(hiscall)  ==  0){
-				if (cqmode == CQ )
-					auto_cq();
+				if (cqmode == CQ ){
+					if (noautocq !=1)
+						auto_cq();
+				}
 				else
 					sendspcall();
 				break;
-			    }
+			}
 
-			 if  (x == 152 ){
+			 if  (x == 152 || x == 229){			// up-arrow or alt-e
 				 	edit_last();
 					break;
 			 }
@@ -174,12 +191,13 @@ printcall();
 
 			x = onechar();
 
+                        
 		switch  (x)
 		{
-			case '+' :
+      			case '+' :
 			{
    				if (strlen(hiscall) > 2) {
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[2]);        /* F3 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -187,14 +205,20 @@ printcall();
 					} else
 						play_file(ph_message[2]);
 
-					if ((cqww == 1) && (strlen(comment) == 0))
+				if (((cqww == 1) || (wazmult == 1))&& (strlen(comment) == 0))
 	 						strcpy(comment, cqzone);
+
+         			 if ((itumult == 1) && (strlen(comment) == 0))
+	 						strcpy(comment, ituzone);
 					x = 92;
 
 				}
 			break;
 			}
 
+
+    
+
 			case 152:                                        // edit last calls....
 			{
 				 	edit_last();
@@ -207,7 +231,7 @@ printcall();
 		 	     	calledit();
 		 	    }
 
-		 		if  (bandinx >= 0 &&  strlen(hiscall) == 0){
+		 		if  (bandinx >= 0 &&  strlen(hiscall) == 0 && no_arrows == 0){
 
 		 			bandinx--;
 					if (bandinx == -1) bandinx = 8;
@@ -222,17 +246,28 @@ printcall();
 		 			if (trx_control == 1) {
 
 						outfreq = (int) (bandfrequency[bandinx] * 1000)    ;
-
 		 			}
+
+#else
+		 			if (trx_control == 1 && rignumber >= 2000) {
+
+						outfreq = (int) (bandfrequency[bandinx] * 1000)    ;
+		 			}
+
 #endif
+						send_bandswitch (bandinx);
 
 		 		}
 
 		 		break;
 		 	}
-		 	case 154:		/* right */
+
+		 	case 154:  /* right */
 		 	{
-		 	 	if  (bandinx <=  8  && strlen(hiscall) == 0){
+		 	 	if (no_arrows ==1)	//don't use arrow keys for band change
+					break;
+
+				if  (bandinx <=  8  && strlen(hiscall) == 0){
 		 	 		bandinx++;
 
 					if (bandinx > 8) bandinx = 0;
@@ -253,7 +288,15 @@ printcall();
 
 							outfreq = (int) (bandfrequency[bandinx] * 1000 )   ;
 		 				}
+#else
+		 				if (trx_control == 1 && rignumber >= 2000) {
+						        freq = bandfrequency[bandinx];
+
+							outfreq = (int) (bandfrequency[bandinx] * 1000 )   ;
+		 				}
+
 #endif
+							send_bandswitch (bandinx);
 
 		 	 		}
 		 	 	break;
@@ -303,6 +346,8 @@ printcall();
 			}
 			case 246:		// Alt-v
 			{
+
+			if (ctcomp == 1) {
 				while (x != 27)  //escape
 				{
 					strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
@@ -345,6 +390,29 @@ printcall();
 					mvprintw(4,1,"           ");
 					printcall();
 				}
+			} else {		// trlog compatible, band switch
+				if  (bandinx >= 0 &&  strlen(hiscall) == 0){
+
+		 			bandinx--;
+					if (bandinx == -1) bandinx = 8;
+
+		 			if ((contest == 1) && (dxped == 0) &&((bandinx == 3) || (bandinx == 5) || (bandinx == 7)))
+		 					bandinx--;
+					attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+		 			mvprintw(12, 0, band[bandinx]);
+		 			printcall();
+		 			i--;
+#ifdef HAVE_LIBHAMLIB
+		 			if (trx_control == 1) {
+
+						outfreq = (int) (bandfrequency[bandinx] * 1000)    ;
+		 			}
+#endif
+						send_bandswitch (bandinx);
+
+		 		}
+
+			}
 			x = -1;
 
 			break;
@@ -363,7 +431,21 @@ printcall();
 					}
 
 				  } else {
+ 						keyspeed = speedup();
+						strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
+						speedbuf[2] =  '\0';
+						attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
 
+		 				mvprintw(0, 14, "%s", speedbuf);
+						printcall();
+
+					}
+
+				break;
+
+			}
+			case 412 :			/* ctrl-pgup, cqdelay (not for TERM=linux */
+			{
 					if  (cqdelay <= 60){
 						cqdelay++;
 						attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
@@ -375,13 +457,11 @@ printcall();
 
 						mvprintw(12, 29 +  strlen(hiscall)  , "");
 					 }
-                  		}
-				break;
 
+				break;
 			}
 
-
-			case 157:                                                   /* pgdown */
+			case 157:                                               /* pgdown */
 			{
 				  if (strlen(hiscall) != 0) {
 
@@ -394,7 +474,24 @@ printcall();
 
 				 } else {
 
-		 			if (cqdelay >= 1){
+						keyspeed = speeddown();
+						strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
+						speedbuf[2] =  '\0';
+						attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		 				mvprintw(0, 14, "%s", speedbuf);
+
+						if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+						else attron(COLOR_PAIR(NORMCOLOR) );
+
+						mvprintw(12, 29 +  strlen(hiscall)  , "");
+
+      			}
+				 break;
+
+			}
+			case 413 :	{			// ctrl-pgdown, cqdelay (not for TERM=linux)
+		 			
+					if (cqdelay >= 1){
 				 		cqdelay--;
 				 		attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
 
@@ -402,9 +499,8 @@ printcall();
 		 				mvprintw(0, 19, "%i",  cqdelay);
 				 	    printcall();
 				 	}
-                  		}
-				 break;
-
+			
+				break;
 			}
 			case '\n': {
 				    if (strlen(hiscall) > 2 && ctcomp == 1) {
@@ -457,7 +553,7 @@ printcall();
 					refresh();
 					break;
 				}
-				case 35:                                                      /*  #  memory */
+				case 35:                                             /*  #  memory */
 				{
 				     if (mem == 0.0) {
 				     	mem = freq;
@@ -509,8 +605,9 @@ printcall();
 				}
 
 				case 129:       /*  F1 */
+//				case KEY_F(1):
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 
 						switch (cqmode){
 							case 0:{
@@ -541,7 +638,7 @@ printcall();
 				}
 				case 130:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[1]);       /* F2 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -553,7 +650,7 @@ printcall();
 				}
 				case 131:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[2]);        /* F3 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -566,7 +663,7 @@ printcall();
 				}
 				case 132:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[3]);       /* F4 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -578,7 +675,7 @@ printcall();
 				}
 				case 133:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[4]);        /* F5 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -589,7 +686,7 @@ printcall();
 				}
 				case 134:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[5]);        /* F6 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -600,7 +697,7 @@ printcall();
 				}
 				case 135:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[6]);        /* F7 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -611,7 +708,7 @@ printcall();
 				}
 				case 136:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE  || trxmode == DIGIMODE) {
 						strcat(buffer, message[7]);       /* F8 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -622,7 +719,7 @@ printcall();
 				}
 				case 137:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[8]);       /* F9 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -633,7 +730,7 @@ printcall();
 				}
 				case 138:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[9]);       /* F10 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -645,7 +742,7 @@ printcall();
 			
 				 case 140:
 				{
-					if (trxmode == CWMODE) {
+					if (trxmode == CWMODE || trxmode == DIGIMODE) {
 						strcat(buffer, message[10]);       /* F11 */
 						sendbuf();
 						mvprintw(12, 29 +  strlen(hiscall), "");
@@ -656,103 +753,8 @@ printcall();
 				}
 				case 141:          					  /* F12 */
 				{
-					if (trxmode != CWMODE) {		// Phone
-						strcpy (mode,  "AUTO_CQ ");
-    					clear_display();
-						nodelay(stdscr,  TRUE);
-				    	while (1){
-							mvprintw(12, 29,"sleeping...  ");
-							refresh();
-							play_file(ph_message[11]);
-							inchar = getch();
-							if (inchar != ERR){
-								if  (cqmode  == CQ )
- 									strcpy (mode, "Log     ");
- 								else
- 									strcpy(mode , "S&P     ");
+					x = auto_cq();
 
-    							clear_display();
-
-								if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
-								else     attron(COLOR_PAIR(NORMCOLOR)   );
-
-								mvprintw(12, 29,"             ");
-								printcall();
-								nodelay(stdscr, FALSE);
-
-								break;
-							}
-							sleep(cqdelay);
-							
-							inchar = getch();
-							if (inchar != ERR){
-								if  (cqmode  == CQ )
- 									strcpy (mode, "Log     ");
- 								else
- 									strcpy(mode , "S&P     ");
-
-    							clear_display();
-								if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
-								else     attron(COLOR_PAIR(NORMCOLOR)   );
-
-								mvprintw(12, 29,"             ");
-								printcall();
-								nodelay(stdscr, FALSE);
-
-								break;
-							}
-						}
-						break;
-					}else {
-						strcpy (mode,  "AUTO_CQ ");
-    					clear_display();
-						nodelay(stdscr,  TRUE);
-				    	while (1){
-				        	strcat(buffer, message[11]);
-							sendbuf();
-							mvprintw(12, 29 +  strlen(hiscall), "");
-							inchar =  getch();
-							if  (inchar  != ERR){
-								mvprintw(12, 29,"             ");
-								break;
-							}
-							if(use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
-							else   attron(COLOR_PAIR(NORMCOLOR)  );
-
-							mvprintw(12, 29," sleeping... ");
-							refresh();
-							sleep(1);
-							printcall();
-							inchar =  getch();
-							if  (inchar  != ERR){
-								mvprintw(12, 29,"             ");
-								break;
-							}
-							sleep(cqdelay);
-							inchar =  getch();
-							if  (inchar  != ERR){
-								mvprintw(12, 29,"             ");
-								break;
-							}
-							mvprintw(12, 29,  "            ");
-							mvprintw(12,29,  "");
-							refresh();
-						}
-						if  (cqmode  == CQ )
- 							strcpy (mode, "Log     ");
- 						else
- 							strcpy(mode , "S&P     ");
-
-    					clear_display();
-
-						if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
-						else     attron(COLOR_PAIR(NORMCOLOR)   );
-
-						mvprintw(12, 29,"             ");
-						printcall();
-						nodelay(stdscr, FALSE);
-					}
-					break;  // end cw
 				}
 		 		case 127:
 		 		{
@@ -779,8 +781,8 @@ printcall();
 			 			}
 					break;
 		 		}
-				case 242:                                                               //alt-R
-				case 243:                                                                // alt-S
+				case 242:                                           //alt-R
+				case 243:                                           // alt-S
 				{
 				if  (showscore_flag == 0)
 					showscore_flag = 1;
@@ -801,11 +803,11 @@ printcall();
 				break;
 				}
 				case 235 :
-				{                                                                             //alt-K     == ctrl-K
+				{                                                      //alt-K     == ctrl-K
 					x = 11;
 				break;
 				}
-				case 225:
+				case 225:		// Alt-a
 				{
 				if (cluster == NOCLUSTER)  {
 					cluster = CLUSTER;                                  // alt-A
@@ -837,7 +839,38 @@ printcall();
 
 				break;
 				}
-				case 234:                                                                   // alt-J
+				case 226 :		// alt-b  (band-up for trlog)
+				{                                                         //alt-K     == ctrl-K
+					if (ctcomp == 0) {
+		 	 			if  (bandinx <=  8  && strlen(hiscall) == 0){
+		 	 				bandinx++;
+
+							if (bandinx > 8) bandinx = 0;
+
+		 	 				if ((contest == 1) && (dxped == 0) && ((bandinx == 3) || (bandinx == 5) || (bandinx == 7)))
+		 	 					bandinx++;
+		 	 				attron(COLOR_PAIR(COLOR_CYAN) | A_STANDOUT);
+		 	 				mvprintw(12, 0, band[bandinx]);
+		 	 				if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD );
+							else    attron(COLOR_PAIR(NORMCOLOR) );
+		 					attron(A_STANDOUT);
+		 					mvprintw(12, 29 +  strlen(hiscall), "");
+
+#ifdef HAVE_LIBHAMLIB
+
+		 					if (trx_control == 1) {
+						        freq = bandfrequency[bandinx];
+								outfreq = (int) (bandfrequency[bandinx] * 1000 )   ;
+		 					}
+#endif
+								send_bandswitch (bandinx);
+
+		 	 			}
+
+					}
+				break;
+				}
+				case 234:                                          // alt-J
 				{
 
 					if (cluster != FREQWINDOW) {
@@ -850,11 +883,16 @@ printcall();
 				}
 				case 232:
 				{
-					show_help();
+			 		endwin();
+			 		system ("clear");
+					system("less help.txt");
+			 		system ("clear");
+					set_term(mainscreen);
+					clear_display();
 					break;
 				}
 
-				case 172:                                                            // alt-,
+				case 172:                             // alt-,
 				case 46:								// . (dot)
 				{
 					attron(COLOR_PAIR(7) | A_STANDOUT);
@@ -969,9 +1007,12 @@ printcall();
 						mvprintw(0,2,"Tune     ");
 						mvprintw(12,29,"");
 						refresh();
-						netkeyer(K_TUNE, "1");      // cw on
-						onechar();					// any character to stop tuning
-						netkeyer(K_TUNE, "0");      // cw off
+						if (tune_val == 0)
+						{
+							netkeyer(K_TUNE, "1");      // cw on
+							onechar();					// any character to stop tuning
+							netkeyer(K_TUNE, "0");      // cw off
+						}
 						k_tune = 0;
 						mvprintw(0,2,"%s", mode);
 						refresh();
@@ -980,7 +1021,7 @@ printcall();
 					 break;
 				}
 
-				case 250:                                    //Alt-z                         // alt-Z
+				case 250:                        //Alt-z
 				{
 
 				 if (cqww == 1){
@@ -1001,11 +1042,11 @@ printcall();
 				case 248:
 				{
 					mvprintw(13,29, "You want to leave tlf? (y/n): ");
-					while (x != 'n') {
+					while (x != 'n' && x != 'N') {
 
 						x = onechar();
 
-						if (x == 'y')  {
+						if (x == 'y' || x == 'Y')  {
 							writeparas();
 							endwin();
 
@@ -1052,19 +1093,21 @@ printcall();
 				}
 			 	case 16:
 			 	{
-			 		muf();
+					miniterm = 0;
+					muf();
+					miniterm = 1;
 			 		clear_display();
-			 		
+
 			 		break;
 			 	}
-     			case 1:                                                               // ctl-A
+     			case 1:                                             // ctl-A
 			 	{
 			 		addspot();
 
 			 		break;
 			 	}
-			case 2:                                                      // ctl-b
-			 	{
+				case 2:                                             // ctl-b
+				{
 					announcefilter=0;
 					cluster = CLUSTER;
 					send_cluster();
@@ -1072,27 +1115,27 @@ printcall();
 			 		break;
 			 	}
 
-			case 6:                                                        // ctl-f
+				case 6:                                             // ctl-f
 			 	{
 			 		change_freq();
 
 			 		break;
 			 	}
-     			case 7:                                                     // ctl-g
+     			case 7:                                             // ctl-g
 			 	{
 			 		grabspot();
 			 		clear_display();
 
 			 		break;
 			 	}
-			case '\"':                                                         // "
-			case 231 :                                                        // alt-g
+				case '\"':                                                       // "
+				case 231 :                                                      // alt-g
 			 	{
 			 		if (lan_active != 0)  talk();
 
 			 		break;
 			 	}
-			case 18 :                                            // ctrl-r
+				case 18 :                                         // ctrl-r
 			 	{
 			 		if (k_pin14 == 0){
 						k_pin14 = 1;
@@ -1104,8 +1147,8 @@ printcall();
 			 		break;
 			 	}
 
-			case 20:                                                // ctrl-t
-			case  233 :                                             // alt-I
+				case 20:                                           // ctrl-t
+				case  233 :                                        // alt-I
      {
 					if (lan_active !=0) {
 
@@ -1135,14 +1178,15 @@ printcall();
 					x = x - 32 ;
 				if (x >= 47 && x <=  90)
 				{
-				if (strlen(hiscall) < 10) {
-					instring[0] = x;
-					instring[1]='\0';
-					addch(x);
-					strcat(hiscall, instring);
-				}
+					if (strlen(hiscall) < 13) {
+						instring[0] = x;
+						instring[1]='\0';
+						addch(x);
+						strcat(hiscall, instring);
+					}
+
 					refresh();
-					
+
 					if (atoi(hiscall) <= 1799) {              /*  no frequency */
 
 
@@ -1158,7 +1202,7 @@ printcall();
 
 					}else {
 						attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
-						mvprintw(24,0, "                                                           ");	
+						mvprintw(24,0, "                                                           ");
 						mvprintw(12,29 + strlen(hiscall), "");
 					}
 
@@ -1166,19 +1210,24 @@ printcall();
 
 				if ((x == '\n') || x == 32 || x == 9 ||  x == 11 || x == 44 || x == 92)
 					break;
-					
+
 			  	time_update();
+
+				if (trxmode == DIGIMODE && keyerport == MFJ1278_KEYER)
+					show_rtty();
+
 		}
 
 
-	
+
 return(x);
 }
 
 int play_file(char *audiofile) {
-						
+
 
 extern int txdelay;
+extern char sc_device[];
 
 int fd;
 char playcommand[40];
@@ -1192,13 +1241,67 @@ char playcommand[40];
 	} else {
 		close (fd);
 		playcommand[0]='\0';
-		strcat (playcommand, "play ");
+		strcat (playcommand, "play -d ");
+		strcat (playcommand, sc_device);
+		strcat (playcommand, " ");
 		strcat (playcommand, audiofile);
-		strcat (playcommand, " &");
+		strcat (playcommand, " > /dev/null ");
 		usleep(txdelay*1000);
 		system(playcommand);
+		printcall();
 	}
 	netkeyer(K_PTT, "0");      // ptt off
 
 return(0);
 }
+
+void send_bandswitch(int freq)
+{
+	extern int use_bandoutput;
+	extern int bandinx;
+	extern int bandindexarray[];
+
+	char outnibble[3];
+	int bandswitch = 0;
+	
+	if (use_bandoutput == 1)
+	{
+		if (freq > 15){			// cannot be a freq...
+			switch ((int)freq) 
+			{
+				case 1800 ... 2000:
+					bandswitch = 1;
+					break;
+				case 3500 ... 4000:
+					bandswitch = 2;
+					break;
+				case 7000 ... 7300:
+					bandswitch = 3;
+					break;
+				case 10100 ... 10150:
+					bandswitch = 4;
+					break;
+				case 14000 ... 14350:
+					bandswitch = 5;
+					break;
+				case 18068 ... 18168:
+					bandswitch = 6;
+					break;
+				case 21000 ... 21450:
+					bandswitch = 7;
+					break;
+				case 24890 ... 24990:
+					bandswitch = 8;
+					break;
+				case 28000 ... 29700:
+					bandswitch = 9;
+			}
+		}else 				// use the bandinx
+			bandswitch = bandinx + 1;
+
+		bandswitch = bandindexarray[bandswitch];
+
+		sprintf(outnibble, "%d", bandswitch);
+		netkeyer(K_SWITCH, outnibble);
+	}
+}
