@@ -23,6 +23,10 @@
  	*--------------------------------------------------------------*/
 
 #include "changepars.h"
+#include "sendbuf.h"
+#include <termios.h>
+
+int debug_tty (void);
 
 int changepars(void){
 
@@ -36,16 +40,19 @@ extern int announcefilter;
 extern int showscore_flag;
 extern int zonedisplay;
 extern int trxmode;
-extern char backgrnd_str[];
 extern char hiscall[];
 extern int rit;
 extern int trx_control;
 extern int editor;
 extern int packetinterface;
+extern int cqdelay;
 extern int ctcomp;
+extern SCREEN *mainscreen;
+extern char config_file[];
+extern int miniterm;
+extern char buffer[];
 
 #ifdef HAVE_LIBHAMLIB
-extern RIG *my_rig;
 extern freq_t outfreq;
 #else
 extern int outfreq;
@@ -53,11 +60,17 @@ extern int outfreq;
 
 extern int simulator;
 extern int keyerport;
+extern char synclogfile[];
+extern int sc_sidetone;
+extern char sc_volume[];
 
 char  parameterstring[20];
-char parameters[38][19];
-int i, k, nopar  = 0;
-int maxpar  = 37;
+char parameters[50][19];
+char cmdstring[80];
+int i, k, x, nopar  = 0;
+int maxpar  = 49;
+int volumebuffer;
+int currentmode = 0;
 
 strcpy(parameters[0] ,  "SPOT");
 strcpy(parameters[1] ,  "MAP");
@@ -89,7 +102,8 @@ strcpy(parameters[26],  "PROP");
 strcpy(parameters[27],  "RITCLEAR");
 strcpy(parameters[28],  "TRXCONTROL");
 strcpy(parameters[29],  "CFG");
-strcpy(parameters[30],  "CWMODE");
+//strcpy(parameters[30],  "CWMODE");
+strcpy(parameters[30],  "CW");
 strcpy(parameters[31],  "SSBMODE");
 strcpy(parameters[32],  "DIGIMODE");
 strcpy(parameters[33],  "PACKET");
@@ -97,6 +111,18 @@ strcpy(parameters[34],  "SIMULATOR");
 strcpy(parameters[35],  "INFO");
 strcpy(parameters[36],  "FREQ");
 strcpy(parameters[37],  "RECONNECT");
+strcpy(parameters[38],  "QUIT");
+strcpy(parameters[39],  "CQDELAY");
+strcpy(parameters[40],  "ADIF");
+strcpy(parameters[41],  "SYNC");
+strcpy(parameters[42],  "RESCORE");
+strcpy(parameters[43],  "SCVOLUME");
+strcpy(parameters[44],  "SCAN");
+strcpy(parameters[45],  "DEBUG");
+strcpy(parameters[46],  "MINITERM");
+strcpy(parameters[47],  "RTTY");
+strcpy(parameters[48], "SOUND");
+strcpy(parameters[49],  "CWMODE");
 
 	nopar = 0;
 	
@@ -113,6 +139,7 @@ strcpy(parameters[37],  "RECONNECT");
 	getstr(parameterstring);
     noecho();
 
+
     for (k = 0;  parameterstring[k]; k++)
      	parameterstring[k]  = toupper(parameterstring[k]);
 
@@ -194,7 +221,13 @@ strcpy(parameters[37],  "RECONNECT");
 		}
 		case  13:			/*  HELP   */
 		{
-			show_help();
+//			show_help();
+			 		endwin();
+			 		system ("clear");
+					system("less help.txt");
+			 		system ("clear");
+					set_term(mainscreen);
+					clear_display();
 			break;
 		}
 		case  14:			/*  DEMODE   */
@@ -254,17 +287,15 @@ strcpy(parameters[37],  "RECONNECT");
 			mvprintw(13, 29,  "writing  cabrillo file");
 			refresh();
 			sleep(1);
-		
+
 			break;
 		}
 		case 19:     		/* EXIT */
 		{
 			writeparas();
-			endwin();
-//			system(cleanup_location);
-//			system("tlf_cleanup");
-
- 			puts("\n\nThanks for using TLF.. 73\n");     	
+			clear();
+           		endwin();
+ 			puts("\n\nThanks for using TLF.. 73\n");
 			exit(0);
 			break;
 		}
@@ -314,13 +345,28 @@ strcpy(parameters[37],  "RECONNECT");
   		case 24:            /* SET PARAMETERS */
 		{
 			clear();
-			if (editor == EDITOR_JOE)
-				system("joe logcfg.dat");
-			else if (editor == EDITOR_VI)
-				system("vi logcfg.dat");
+			if (editor == EDITOR_JOE){
+				strcpy (cmdstring, "joe ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
+			else if (editor == EDITOR_VI){
+				strcpy (cmdstring, "vi ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
+			else if (editor == EDITOR_MC){
+				strcpy (cmdstring, "mcedit ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
 			else
-				system("e3 logcfg.dat");
-			
+{
+				strcpy (cmdstring, "e3 ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
+
 			read_logcfg();
 			writeparas();
 			mvprintw(24,0, "Logcfg.dat loaded, parameters written..");
@@ -364,7 +410,7 @@ strcpy(parameters[37],  "RECONNECT");
 					trx_control = 0;
 				else {
 					trx_control = 1;
-				
+
 				}
 				if (trx_control == 1){
 					mvprintw(13, 29,  "TRX control on");
@@ -379,13 +425,27 @@ strcpy(parameters[37],  "RECONNECT");
 		case 29:            /* LOAD PARAMETERS */
 		{
 			clear();
-			if (editor == EDITOR_JOE)
-				system("joe logcfg.dat");
-			else if (editor == EDITOR_VI)
-				system("vi logcfg.dat");
+			if (editor == EDITOR_JOE){
+				strcpy (cmdstring, "joe ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
+			else if (editor == EDITOR_VI){
+				strcpy (cmdstring, "vi ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
+			else if (editor == EDITOR_MC){
+				strcpy (cmdstring, "mcedit ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
 			else
-				system("e3 logcfg.dat");
-
+{
+				strcpy (cmdstring, "e3 ");
+				strcat (cmdstring, config_file);
+				system(cmdstring);
+				}
 			read_logcfg();
 			writeparas();
 			mvprintw(24,0, "Logcfg.dat loaded, parameters written..");
@@ -394,10 +454,19 @@ strcpy(parameters[37],  "RECONNECT");
 			break;
 		}
 		case 30:				/* CW  */
+		case 49:
 		{
+		if (keyerport == MFJ1278_KEYER) {
+			strcpy (buffer, "MODE CW,30");
+			buffer[7] =  '\015';
+			buffer[8] =  'K';
+			buffer[9] =  '\015';
+			buffer[10] = '\0';
+			sendbuf();
+		}
 			trxmode = CWMODE;
 
-			if(trx_control == 1)  
+			if(trx_control == 1)
 				outfreq =  SETCWMODE;
 			break;
 		}
@@ -457,7 +526,13 @@ strcpy(parameters[37],  "RECONNECT");
 		}
 		case 35:				/* INFO  */
 		{
+
+			miniterm = 0;
 			networkinfo();
+			miniterm = 1;
+
+			if (currentmode == DIGIMODE)
+				trxmode = DIGIMODE;
 			break;
 		}
 		case 36:             /* CLOFF  */
@@ -476,6 +551,172 @@ strcpy(parameters[37],  "RECONNECT");
 			break;
 		}
 
+		case 38:     		/* EXIT=QUIT */
+		{
+			writeparas();
+			endwin();
+ 			puts("\n\nThanks for using TLF.. 73\n");
+             exit(0);
+			break;
+		}
+		case 39 :
+		{
+			mvprintw(12,29, "CQD: pgup/dwn", cqdelay);
+			refresh();
+			
+			x = 1;
+			while (x) {
+				x=onechar();
+
+				switch (x) {
+					case 156: {
+						if  (cqdelay <= 60){
+							cqdelay++;
+							attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		 					mvprintw(0, 19, "  ");
+		 					mvprintw(0, 19, "%i",  cqdelay);
+							break;
+
+						}
+					}
+					case 157: {
+						if (cqdelay >= 1){
+				 			cqdelay--;
+				 			attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+
+		 					mvprintw(0, 19, "  ");
+		 					mvprintw(0, 19, "%i",  cqdelay);
+							break;
+
+						}
+					default:
+						x = 0;
+					}
+
+				}
+			}
+
+			if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR)  | A_BOLD );
+			else attron(COLOR_PAIR(NORMCOLOR) );
+
+			mvprintw(12, 29 +  strlen(hiscall)  , "");
+			break;
+
+
+		}
+		case 40: {
+			write_adif();
+			mvprintw(13, 29,  "writing adif file");
+			refresh();
+			sleep(1);
+
+			break;
+		}
+			case 41:            /* SYNC */
+		{
+			if (strlen(synclogfile) > 0)
+				synclog(synclogfile);
+			scroll_log();
+			readcalls();
+		    clear_display();
+			break;
+		}
+			case 42:            /* RESCORE */
+		{
+			readcalls();
+		    clear_display();
+			break;
+		}
+			case 43:            /* SCVOLUME */		/* set soundcard volume */
+		{
+			if (sc_sidetone == 0) break;
+
+			mvprintw(12, 29, "Vol: %d", atoi(sc_volume));
+			volumebuffer = atoi(sc_volume);
+
+			x = 1;
+			while (x)
+			{
+				x=onechar();
+
+				switch (x) {
+					case 156: {
+						if  (volumebuffer <= 99){
+							volumebuffer +=5;
+							attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+		 					mvprintw(12, 34, "  ");
+		 					mvprintw(12, 34, "%d",  volumebuffer);
+							break;
+
+						}
+					}
+					case 157: {
+						if (volumebuffer >= 6)
+						{
+				 			volumebuffer -= 5;
+				 			attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+
+		 					mvprintw(12, 34, "  ");
+		 					mvprintw(12, 34, "%d",  volumebuffer);
+							break;
+
+						}
+					default:
+						x = 0;
+					}
+					if (volumebuffer >= 0 && volumebuffer <=99)
+						sprintf(sc_volume, "%d", volumebuffer);
+
+				}
+				netkeyer (K_STVOLUME, sc_volume);
+			}
+
+
+		    clear_display();
+			break;
+		}
+		case 44:            /* SCAN */
+		{
+			miniterm = 0;
+			testaudio();
+			clear_display();
+		    	miniterm = 1;
+			break;
+		}
+		case 45:            /* DEBUG */
+		{
+			debug_tty();
+		    clear_display();
+			break;
+		}
+		case 46:		/* MINITERM ON/OFF */
+		{
+			if (miniterm == 1)
+				miniterm = 0;
+			else
+				miniterm = 1;
+			break;
+		}
+		case 47:		/* Initialize RTTY mode  (MFJ1278B controller)*/
+		{
+			strcpy (buffer, "MODE VB");
+			buffer[7] =  '\015';
+			buffer[8] =  'K';
+			buffer[9] =  '\015';
+			buffer[10] = '\0';
+			sendbuf();
+			trxmode=DIGIMODE;
+
+			break;
+		}
+		case 48:            /* SOUND */
+		{
+			clear_display();
+			record();
+			clear_display();
+			break;
+		}
+
 		default:
 		{
 		
@@ -489,20 +730,8 @@ strcpy(parameters[37],  "RECONNECT");
 		writeparas();
 		}
 	else{
-		
-		mvprintw(12, 29, "INVALID PAR!");
-		backgrnd_str[80]  = '\0';
-		mvprintw(13,  0, backgrnd_str);
-		mvprintw(13,0, "");
-		
-		for (i  = 0 ;  i <= maxpar ;  i++){	
-			printw( parameters[i] );
-			addch(' ');
-			}
-			
-		refresh();
-		sleep(2);
-		
+		if (packetinterface > 0) packet();
+
 	}
 	
 	refresh();
@@ -514,7 +743,7 @@ strcpy(parameters[37],  "RECONNECT");
 	mvprintw(12, 29, "");
 	refresh();
 	hiscall[0] = '\0';
-	
+
 
  return(0);
  }
@@ -524,6 +753,7 @@ strcpy(parameters[37],  "RECONNECT");
 int networkinfo(void){
 
 extern int use_rxvt;
+extern int use_bandoutput;
 extern int recv_packets;
 extern int recv_error;
 extern int send_packets[];
@@ -531,7 +761,12 @@ extern int send_error[];
 extern int lan_active;
 extern int nodes;
 extern char bc_hostaddress[MAXNODES][16];
-
+extern char config_file[];
+extern char whichcontest[];
+extern char pr_hostaddress[];
+extern char tncportname[];
+extern char rigportname[];
+extern char logfile[];
 
 int i, j, inode, key;
 
@@ -554,6 +789,19 @@ int i, j, inode, key;
   			mvprintw(4 + inode,10, "%s", bc_hostaddress[inode]);
   			mvprintw(4 + inode, 28, "Packets sent: %d | %d ", send_packets[inode], send_error[inode], nodes);
 	  	}
+		
+		if (strlen(config_file) > 0) mvprintw(6 + inode, 10, "Config file: %s", config_file);
+		else mvprintw(6 + inode, 10, "Config file: /usr/local/share/tlf/logcfg.dat");
+		mvprintw(7 + inode, 10, "Contest    : %s", whichcontest);
+		mvprintw(8 + inode, 10, "Logfile    : %s", logfile);
+
+		mvprintw(9 + inode, 10, "Cluster    : %s", pr_hostaddress);
+		mvprintw(10 + inode, 10, "TNCport    : %s", tncportname);
+		mvprintw(11 + inode, 10, "RIGport    : %s", rigportname);
+		if (use_bandoutput == 1) mvprintw(12 + inode, 10, "Band output: on");
+		else mvprintw(12 + inode, 10, "Band output: off");
+
+
 	  	refresh();
 
 	  	mvprintw(23,22," --- Press a key to continue --- ");
@@ -588,6 +836,7 @@ extern int multcount;
 int j, k,key, vert, hor, cnt, found;
 char mprint[50];
 char chmult[4];
+char ch2mult[4];
 
 		clear();
 
@@ -610,14 +859,13 @@ char chmult[4];
 
 					found = 0;
 					for (j = 0; j < multcount+1; j++) {
-						strncpy (chmult, mults_possible[cnt], 3);
-						if (strlen(chmult) == 2) strcat (chmult, " ");
+						strcpy (chmult, mults_possible[cnt]);
+						strcpy (ch2mult, mults[j]);
+						
+						if (ch2mult[2]== ' ') ch2mult[2] = '\0';
 
-//mvprintw(14,0, "|%s|%s|", mults[j], chmult);
-//refresh();
-//sleep(1);
 
-						if (strcmp(mults[j], chmult) == 0)
+						if (strcmp(ch2mult, chmult) == 0)
 							found = 1;
 					}
 					if (found == 1)
@@ -639,7 +887,7 @@ char chmult[4];
 			}
 		}
 
-		if (serial_section_mult == 1|| sectn_mult == 1) {
+		if (serial_section_mult == 1|| (sectn_mult == 1 && arrlss != 1)) {
 			mvprintw(0, 30, "REMAINING SECTIONS");
 			cnt=0;
 			for (vert = 2;  vert < 22; vert++) {
@@ -654,8 +902,7 @@ char chmult[4];
 					if (strlen(mprint) > 3) mprint[4] = '\0';
 
 					for (k=1 ; k <= MAX_MULTS; k++) {
-						if (strstr(mults[k], mults_possible[cnt]) != NULL)
-							break;
+						if (strstr(mults[k], mults_possible[cnt]) != NULL) break;
 					}
 
 					if ((mult_bands[k] &  BAND160 ) != 0) strcat (mprint, "*");
@@ -701,3 +948,166 @@ char chmult[4];
 return(0);
 
 }
+
+/* ----------------------------------- radio link debug --------------------------------- */
+
+int debug_tty (void) {
+
+extern char rigportname[];
+extern int serial_rate;
+
+int fdSertnc;
+int tncport = 0;
+int i;
+struct termios termattribs;
+char line[20] = "?AF\015";
+char inputline[80] = "";
+const char eom[2] = {'\015' , '\0'};
+
+/* initialize ttyS0*/
+
+		for (i = 0; i < 24; i++)
+			mvprintw(i,0, "                                                                                ");
+		refresh();
+
+		if (rigportname[strlen(rigportname) - 1] == '\n')
+				rigportname[strlen(rigportname) -1 ] = '\0'; // remove \n
+
+                mvprintw(4,0, "Trying to open %s ", rigportname);
+		refresh();
+
+		if (tncport == 1) {
+    			if ((fdSertnc = open("/dev/ttyS2", O_RDWR | O_NONBLOCK)) < 0) {
+                		mvprintw(5,0, "open of /dev/ttyS2 failed!!!");
+				refresh();
+				sleep(2);
+                		return(-1);
+    			}
+ 		}else if(tncport == 2){
+
+   			if ((fdSertnc = open("/dev/ttyS1", O_RDWR | O_NONBLOCK)) < 0) {
+                		mvprintw(5,0,  "open of /dev/ttyS1 failed!!!");
+				refresh();
+				sleep(2);
+				return(-1);
+    			}
+    		}
+		else {
+   			if ((fdSertnc = open(rigportname, O_RDWR | O_NONBLOCK)) < 0) {
+                		mvprintw(5,0,  "open of %s failed!!!", rigportname);
+				refresh();
+				sleep(2);
+				return(-1);
+    			}
+
+		}
+
+
+
+	termattribs.c_iflag = IGNBRK | IGNPAR | IMAXBEL | IXOFF;
+    	termattribs.c_oflag = 0;
+   	termattribs.c_cflag = CS8 | CSTOPB | CREAD | CLOCAL;
+
+
+    	termattribs.c_lflag = 0;		    /* Set some term flags */
+
+    	/*  The ensure there are no read timeouts (possibly writes?) */
+    	termattribs.c_cc[VMIN] = 1;
+    	termattribs.c_cc[VTIME] = 0;
+
+	switch(serial_rate) {
+
+ 			case   1200 : {
+				cfsetispeed(&termattribs,B1200);	    /* Set input speed */
+    				cfsetospeed(&termattribs,B1200);	    /* Set output speed */
+			 break;
+			}
+
+			case   2400 : {
+				cfsetispeed(&termattribs,B2400);	    /* Set input speed */
+    				cfsetospeed(&termattribs,B2400);	    /* Set output speed */
+			 break;
+			 }
+
+			case   4800 : {
+				cfsetispeed(&termattribs,B4800);	    /* Set input speed */
+    				cfsetospeed(&termattribs,B4800);	    /* Set output speed */
+			 break;
+			 }
+
+			case   9600 : {
+				cfsetispeed(&termattribs,B9600);	    /* Set input speed */
+    				cfsetospeed(&termattribs,B9600);	    /* Set output speed */
+			 break;
+			 }
+			case   57600 : {
+				cfsetispeed(&termattribs,B57600);	    /* Set input speed */
+    				cfsetospeed(&termattribs,B57600);	    /* Set output speed */
+			 break;
+			 }
+
+			default:   {
+
+				cfsetispeed(&termattribs,B9600);	    /* Set input speed */
+    				cfsetospeed(&termattribs,B9600);	    /* Set output speed */
+			}
+	}
+
+	tcsetattr(fdSertnc,TCSANOW,&termattribs);  /* Set the serial port */
+
+	mvprintw(6,0, "%s opened...", rigportname);
+	refresh();
+
+	mvprintw(13,0, "Input command: ");
+	refresh();
+	echo();
+	getnstr(line,  12);
+	noecho();
+	strcat(line, eom);
+
+/* send message */
+	mvprintw (7,0, "sending message to trx: %s" , line );
+	mvprintw(7,40, "Length = %d characters",strlen(line));
+	refresh();
+
+	write (fdSertnc, line, strlen(line));
+
+	mvprintw (8,0, "receiving message from trx"); refresh();
+	usleep(30000);
+
+
+		if(fdSertnc > 0) {
+
+			int j = 0;
+
+			i = read (fdSertnc, inputline, BUFFERSIZE-1);
+
+			if (i > 0) {
+				for (j=0; j<i; j++){
+					mvprintw (10, j*10, "%#x", (char) inputline[j]);
+					mvprintw(11, j, "%c", (char) inputline [j]);
+					mvprintw(12, j * 10, "%d", (char) inputline[j] & 0xff);
+					refresh();
+				}
+			}
+			mvprintw(8,40, "Length = %d characters", i);
+			if (inputline[0] == '@' && inputline [1] == 'A' && inputline[2] != 'F') {
+				mvprintw(20, 0, "Frequency = %d Hz", ( (inputline[3] & 0xff) * 65536) + (( inputline[4] & 0xff) * 256) +  (inputline[5] & 0xff));
+			}
+
+			refresh();
+			sleep(1);
+		}
+
+
+	mvprintw(23,0, "done"); refresh();
+	i = getch();
+
+/* close the tty */
+
+	 if (fdSertnc > 0)	 close (fdSertnc);
+
+
+
+return(0);
+}
