@@ -9,8 +9,8 @@ extern int bandinx;
 
 int cluster_bg(int cluster) {
 
-extern char spot_ptr[100][82];
-extern int spotarray[];
+extern char spot_ptr[MAX_SPOTS][82];
+extern int spotarray[MAX_SPOTS];
 extern char spotinfo[32][82];
 extern int cluster;
 extern int announcefilter;
@@ -36,6 +36,9 @@ char textbuffer[82];
 
 
 				k = getclusterinfo();
+				
+				if (k > (MAX_SPOTS -2))
+					k = MAX_SPOTS -2;
 
 					if (clustermode != 9) {                                        // map
 
@@ -77,6 +80,10 @@ char textbuffer[82];
 				if (cluster  == CLUSTER){             /* all cluster info  */
 
 		   			k = getclusterinfo();
+					
+					if (k > (MAX_SPOTS -2))
+						k = MAX_SPOTS -2;
+
 
 				}
 
@@ -86,7 +93,7 @@ return(0);
 
 int getclusterinfo(void){
 
-extern char spot_ptr[100][82];
+extern char spot_ptr[MAX_SPOTS][82];
 extern char lastwwv[];
 extern int ptr;
 extern int spot_rdr;
@@ -109,7 +116,7 @@ bg = spot_rdr;
 i = 0;
 si = 0;
 
-for (si = 0; si < 100; si++)
+for (si = 0; si < (MAX_SPOTS -2); si++)
 	spotarray[si]=-1;
 si = 0;
 
@@ -229,7 +236,7 @@ return (si -1);
 
 ------------------------------------------------------*/
 
-char *bandmap[200];
+char *bandmap[MAX_SPOTS];
 struct tln_logline *temps;
 int allspots = 0;
 
@@ -238,7 +245,7 @@ int allspots = 0;
 int loadbandmap(void) {
 
 extern int cluster;
-extern  char *bandmap[200];
+extern  char *bandmap[MAX_SPOTS];
 extern struct tln_logline *loghead;
 extern struct tln_logline *temps;
 extern struct tm *time_ptr;
@@ -251,6 +258,7 @@ extern int xplanet;
 extern char markerfile[];
 extern int countrynr;
 extern char lastmsg[];
+extern char cqzone[];
 
 int i = 0, j, jj, changeflg, k, m, x, y,done;
 int in_map;
@@ -262,8 +270,8 @@ int linepos;
 int worked;
 int thisband = 10;
 int dupe;
-int spot_age[200];
-float spot_freq[200];
+int spot_age[MAX_SPOTS];
+float spot_freq[MAX_SPOTS];
 float freqbuffer;
 int timebuff;
 
@@ -278,10 +286,9 @@ char spotline[38];
 char tmp1[81];
 char tmp2[81];
 char callcopy[81];
+char cqzonebuffer[3];
 FILE *fp;
 char marker_out[40];
-char datacopy[80];
-int ic;
 int lon;
 int lat;
 int yy,zz;
@@ -490,7 +497,11 @@ for (j=linepos; j < linepos+8; j++)  {
 				}
 			}
 			yy = countrynr;
+			strcpy(cqzonebuffer, cqzone);
+
 			x =  getctydata(callcopy);
+			
+			strcpy(cqzone, cqzonebuffer); // to be fixed: getctydata.c should not change cqzone
 			countrynr = yy;
 
 
