@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudx.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,12 +25,14 @@
 #include "getexchange.h"
 #include "recall_exchange.h"
 
+int play_file(char *audiofile);
 
 int getexchange(void)
 {
 extern int use_rxvt;
 extern char comment[];
 extern char cqzone[];
+extern char ituzone[];
 extern char my_rst[];
 extern int cury, curx;
 extern char message[15][80];
@@ -40,12 +42,9 @@ extern char buffer[];
 extern char qsonrstr[];
 extern int cqww;
 extern int wpx;
-extern int pfxmult;
-extern int exc_cont;
-extern char continent[];
 extern int pacc_pa_flg;
 extern int arrldx_usa;
-extern int arrl_fd;                                                                                                            
+extern int arrl_fd;
 extern int exchange_serial;
 extern int countrynr;
 extern int mycountrynr;
@@ -57,12 +56,17 @@ extern int lan_active;
 extern char lastqsonr[];
 extern char qsonrstr[];
 extern char call[];
-extern int arrlss;
 extern char section[];
 extern int serial_section_mult;
 extern int sectn_mult;
 extern int dx_arrlsections;
 extern int ctcomp;
+extern int wazmult;
+extern int itumult;
+extern int pfxmult;
+extern int exc_cont;
+extern char continent[];
+
 
 int  i;
 int x = 0;
@@ -91,13 +95,16 @@ instring[1] = '\0';
 	if(arrl_fd == 1)
 		retval = recall_exchange();
 
-	if ((cqww == 1) && (strlen(comment) == 0) && (strlen(hiscall) != 0)) {
-	 	strcpy(comment, cqzone);
+	if ( ((cqww == 1)||(wazmult == 1)||(itumult == 1) )&& (strlen(comment) == 0) && (strlen(hiscall) != 0)) {
+          if (itumult==1)
+          strcpy(comment, ituzone);
+          else
+          strcpy(comment, cqzone);
     	}
+ 	if ((exc_cont == 1) && (strlen(comment) == 0) && (strlen(hiscall) != 0)) {
+ 	 	strcpy(comment, continent);
+     	}
 
-	if ((exc_cont == 1) && (strlen(comment) == 0) && (strlen(hiscall) != 0)) {
-	 	strcpy(comment, continent);
-    	}
 
 
 	if (use_rxvt == 0) attron(COLOR_PAIR(NORMCOLOR) | A_BOLD  );
@@ -126,14 +133,22 @@ instring[1] = '\0';
 						
 						case 27:
 						{
-						 comment[0] = '\0';
-						 mvprintw(12,54, "                          ");
-						 mvprintw(12, 54, "");
-						 stoptx();
-						 i=0;
+						 if (comment[0] != '\0')
+						 {
+						 	comment[0] = '\0';
+						 	mvprintw(12,54, "                          ");
+						 		mvprintw(12, 54, "");
+						 	stoptx();
+						 	i=0;
 							break;
+						 } else
+						 {
+							hiscall[0] = '\0';
+							x = 9;
+							break;
+						 }
 						}
-						case 160:                                        // for CT compatibility
+						case 160:                         // for CT compatibility
 						{
 						if (trxmode == CWMODE) {
 							strcat (buffer, message[1]);
@@ -285,7 +300,8 @@ instring[1] = '\0';
 			}
 
 
-			if  (wpx == 1 && pfxmult == 0) {                      /* align serial nr. */
+ 			if  (wpx == 1 && pfxmult == 0) {                      /* align serial nr. */
+
 			 	if ((strlen(comment)  ==  1) || (comment[1] == ' ')){
 			 	 	strcpy(commentbuf,  comment);
 			 	 	comment[0]  = '\0';
@@ -313,7 +329,7 @@ instring[1] = '\0';
 			 	 	strcpy (comment, commentbuf);
 			 	}
 			 	if ((comment[2] == ' ') && (comment[1] != ' ')) {
-			 	
+
 			 	 	strcpy(commentbuf, "0");
 			 	 	commentbuf[1] = comment[0];
 			 	 	commentbuf[2] = comment[1];
@@ -349,7 +365,8 @@ instring[1] = '\0';
 			else if  (((serial_section_mult ==1) || (sectn_mult == 1))  && ((x != 9) && (strlen(section) < 1))) {
 				mvprintw(13,54, "section?");
 				mvprintw(12,54, comment);
-				x = 0;
+				refresh();
+//				x = 0;
 			} else
 				break;
 
@@ -425,15 +442,18 @@ int checkexchange (int x) {
 		"bffu",
 		"affu",
 		"affb",
-		"affa" ,
+		"affa",
 		"bffa"
 		};
-	char secpats[7][6] =
+	char secpats[10][6] =
 		{
+		"fab",
 		"faab",
 		"faaab",
+		"bab",
 		"baab",
 		"baaab",
+		"bau",
 		"baau",
 		"baaau",
 		"baafb"
@@ -455,13 +475,15 @@ int checkexchange (int x) {
 		"bffu",
 		"bfu"
 		};
-	char sectionpats[7][6] =
+	char sectionpats[9][6] =
 		{
 		"uab",
 		"uaab",
 		"uaaab",
+		"uau",
 		"uaau",
 		"uaaau",
+		"bab",
 		"baab",
 		"baaab"
 		};
@@ -694,7 +716,7 @@ if (arrlss == 1) {                    // ---------------------------arrls-------
 // get section
 				hr=0;
 
-				for (ii = 0; ii < 7; ii++) {
+				for (ii = 0; ii < 10; ii++) {
 
 					hr = getlastpattern(secpats[ii]);
 
@@ -703,11 +725,14 @@ if (arrlss == 1) {                    // ---------------------------arrls-------
 							strncpy (checksection, comment+(hr), 3);
 							checksection[3]='\0';
 
-							for (jj=0 ; jj < MAX_MULTS ; jj++) {
+							for (jj=0 ; jj < max_multipliers-1 ; jj++) {
 
-								if ((strlen(mults_possible[jj] )>=1) &&  (strstr(checksection, mults_possible[jj]) != NULL)) {
+								if ((strlen(mults_possible[jj] )>=1) &&
+									(strstr(checksection, mults_possible[jj]) != NULL) &&
+									(strlen(checksection) == strlen(mults_possible[jj]))) {
 
 									strcpy (section, mults_possible[jj]);
+									break;
 								}
 							}
 					}
@@ -727,6 +752,11 @@ if (arrlss == 1) {                    // ---------------------------arrls-------
 	strcat(ssexchange,check);
 	strcat (ssexchange, " ");
 	strcat(ssexchange,section);
+	
+	mvprintw(12, 54, comment);
+	refresh();
+	
+	return(x);   // end arrlss
 }
 
 // ---------------------------------serial+section-----------------------------------------
@@ -768,14 +798,22 @@ if ((serial_section_mult == 1) || (sectn_mult == 1) || dx_arrlsections == 1) {
 
 					if (hr > 0)  {
 
+							memset (checksection, 0, 29);
 							strncpy (checksection, comment+(hr), 3);
-							checksection[3]='\0';
+							if (checksection[strlen(checksection)-1] == ' ')
+							{
+								checksection[strlen(checksection)-1] = '\0';
+							}
+//							checksection[3]='\0';
 
-							for (jj=0 ; jj < MAX_MULTS ; jj++) {
-
-								if ((strlen(mults_possible[jj] )>=1) &&  (strstr(checksection, mults_possible[jj]) != NULL)) {
+							for (jj=0 ; jj < MAX_MULTS ; jj++)
+							{
 
+//								if ((strlen(mults_possible[jj] )>=1) &&  (strstr(checksection, mults_possible[jj]) != NULL))
+								if ((strlen(mults_possible[jj] )>=1) &&  (strcmp(checksection, mults_possible[jj]) == 0))
+								{
 									strcpy (section, mults_possible[jj]);
+									break; // new
 								}
 							}
 					}
@@ -794,7 +832,7 @@ if ((serial_section_mult == 1) || (sectn_mult == 1) || dx_arrlsections == 1) {
 							strncpy (checksection, comment, 3);
 							checksection[3]='\0';
 
-							for (jj=0 ; jj < MAX_MULTS ; jj++) {
+							for (jj=0 ; jj < max_multipliers ; jj++) {
 
 								if ((strlen(mults_possible[jj] )>=1) &&  (strstr(checksection, mults_possible[jj]) != NULL)) {
 
@@ -882,10 +920,11 @@ if ((serial_section_mult == 1) || (sectn_mult == 1) || dx_arrlsections == 1) {
 	mvprintw(8, 73, "%s", section);
 	ssexchange[0]='\0';
 
-	if (serial_section_mult == 1) {
+/*	if (serial_section_mult == 1) {
 		strcat(ssexchange,serial);
 		strcat (ssexchange, " ");
 	}
+*/		
 	strcat(ssexchange,section);
 
 
