@@ -23,8 +23,9 @@
  	*        also gets the nr of the last qso from  the logfile
  	*--------------------------------------------------------------*/
 
+#include "globalvars.h"
 #include "getmessages.h"
- 	
+
 int getmessages(void)
 {
 
@@ -33,60 +34,23 @@ extern int mycountrynr;
 extern char mycqzone[];
 extern char mycontinent[];
 extern char datalines[MAX_DATALINES][81];
-extern char message[15][80];
-extern char headerline[];
 extern char logfile[];
-extern char whichcontest[];
-extern char para_word[];
-extern int shortqsonr;
-extern int cluster;
-extern int searchflg;
-extern int demode;
-extern int announcefilter;
-extern int showscore_flag;
-extern int speed;
-extern int cqdelay;
-extern int trxmode;
 extern int qsonum;
-extern char sp_return[];
-extern char cq_return[];
 extern char qsonrstr[];
-extern char logline0[];
-extern char logline1[];
-extern char logline2[];
-extern char logline3[];
-extern char logline4[];
 extern char backgrnd_str[];
 extern char C_QTH_Lat[];
 extern char C_QTH_Long[];
 extern int emptydir;
 
-extern struct tm *time_ptr;
 
 FILE *fp;
-int  n = 120;
+
 int i, ii;
-char inputbuffer[160];
-char time_buf[80];
 char logline[5][81];
-char logfiletest[40] = "";
 char printcall[12] = "";
 
-if  ( (fp = fopen(".paras","r"))  == NULL){
-		fprintf(stdout,  "Error opening parameters file.\n");
-	}
-
-while(1){
-	fgets (inputbuffer, n,  fp);
-	if (inputbuffer[0] != '#')
-		break;
-}
-
 printw("\n     Call = ");
 
-if (strlen(call) < 2)
-	strcpy (call, inputbuffer);
-
 printcall[0] = '\0';
 strncat(printcall, call, strlen(call)-1 );
 printw(printcall);
@@ -112,120 +76,21 @@ printw(mycontinent);
 printw("\n\n");
 refresh();
 
-for ( i = 0; i <= 13; i++){
-	while(1){
-		fgets  (inputbuffer, n,  fp);
-		if (inputbuffer[0] != '#')
-			break;
-	}
-
-	
-	strcpy (message[i], inputbuffer);
-
-}
-strcpy(sp_return, message[12]);
-strcpy(cq_return, message[13]);
-
-while(1){
-	fgets (headerline, 80,  fp);
-	headerline[59] = '\n';         /* limit the length */
-	headerline[60] = '\0';
-	
-	if (headerline[0] != '#')
-		break;
-}
-
-
-while(1){
-	fgets (logfiletest, 80,  fp);
-	if (logfiletest[0] != '#')
-		break;
-}
-
-if (strlen(logfile) < 2) {
-
-	logfile[0] = '\0';
-
-	strcat (logfile,  logfiletest);
-	logfile[strlen(logfile)-1] = '\0';
-}
-
-while(1){
-	fgets (whichcontest, 80,  fp);
-	if (whichcontest[0] != '#')
-		break;
-}
-whichcontest[strlen(whichcontest)-1] ='\0';        /* which contest are we in ? */
-
-while(1){
-	fgets (para_word, 81,  fp);
-	if (para_word[0] != '#')
-		break;
-}
-if (para_word[0] == 'S')
-	shortqsonr  = 1;
-else
-	shortqsonr  = 0;
-	
-if (para_word[1] == 'A')
-	cluster = 3;
-else if  (para_word[1] == 'M')
-	cluster = 1;
-else if (para_word[1] ==  'S')
-	cluster = 2;
-else if  (para_word[1]  == 'O')
-	cluster = 0;
-	
-if (para_word[2] == 'D')
-	searchflg = 1;
-else
-	searchflg = 0;
-
-if (para_word[3] == 'D')
-	demode = 1;
-else
-	demode =  0;
-/*
-if (para_word[4]  == 'C')
-	contest = 1;
-else
-	contest = 0;
-*/	
-if (para_word[5] == 'F')
-	announcefilter = 1;
-else
-	announcefilter = 0;
-
-if (para_word[6] ==  'S')
-	showscore_flag = 1;
-else
-	showscore_flag = 0;
-/*
-if ((para_word[7] >= 49) && (para_word[7] < 68))
-	speed  = (para_word[7] - 48);
-
-if (para_word[8] >= 48)
-	cqdelay = (para_word[8] - 48);
-
-if (para_word[9] == 'C')
-	trxmode = CWMODE;
-else
-	trxmode = SSBMODE;
-*/	
-fclose(fp);
-
 checklogfile();
 
 if  ( (fp = fopen(logfile,"r"))  == NULL){
-		fprintf(stdout,  "Error opening file.\n");
+		printw("\nError opening logfile.\nExiting...\n");
+		refresh();
+		sleep(5);
+		exit(1);
 }
 
 for ( i = 5; i >= 1; i--){
-	
+
 	ii = 5 - i;
-	
+
 	if (fseek(fp, -1 * i * 81, SEEK_END) == 0){
-		
+
 		fgets  (logline[ii], 85,  fp);
 	}
 	else {
@@ -285,7 +150,7 @@ if (emptydir == 1) {
 	printw ("             T    L      FFFFF\n");
 	printw ("             T    L      F    \n");
 	printw ("             T    LLLLL  F    \n");
-	printw ("\n\n This program is copyright 2001, 2002, 2003 by Rein Couperus, PA0RCT\n\n");
+	printw ("\n\n This program is copyright 2002, 2003, 2004 by Rein Couperus, PA0R\n\n");
 	printw (" It is free software; you can redistribute it and/or modify");
 	printw (" it under the terms of the GNU General Public License as published by");
 	printw (" the Free Software Foundation; either version 2 of the License, or");
