@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudxf.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define NEWCODE = 1
 
 #include "tlf.h"
+#include "globalvars.h"
 #include "main.h"
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -30,10 +31,11 @@
   SCREEN *packetscreen;
   WINDOW *sclwin, *entwin;
 
- extern int lan_active;
+	extern int lan_active;
 
   int prsock = 0;
-  char pr_hostaddress[16]="131.155.192.179";
+  char pr_hostaddress[48]="131.155.192.179";
+  char config_file[80] = "";
   int portnum = 0;
   struct tln_logline  *loghead = NULL;
   struct tln_logline   *logtail = NULL;
@@ -41,14 +43,27 @@
   struct tln_logline *temp=NULL;
 
   int use_rxvt = 0;
+  int use_xterm = 0;
+
+  int tlfcolors[8][2]= {{COLOR_BLACK, COLOR_WHITE},
+  						{COLOR_GREEN, COLOR_YELLOW},
+						{COLOR_WHITE, COLOR_RED},
+						{COLOR_CYAN, COLOR_WHITE},
+						{COLOR_WHITE, COLOR_BLACK},
+						{COLOR_MAGENTA, COLOR_WHITE},
+						{COLOR_BLUE, COLOR_YELLOW},
+						{COLOR_WHITE, COLOR_BLACK}
+						};
   int debugflag = 0;
   int editor = EDITOR_JOE;
   int use_vk = 0;
+  int tune_val = 0;
+  int use_bandoutput = 0;
+  int no_arrows = 0;
+  int bandindexarray[10] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
   int cqww = 0;
   int cqwwm2=0;
   int wpx  =  0;
-  int pfxmult = 1;
-  int exc_cont = 0;
   int dxped = 0;
   int sprint = 0;
   int arrldx_usa = 0;
@@ -57,12 +72,18 @@
   int pacc_pa_flg = 0;
   int universal=0;
   int addcallarea;
+  int pfxmult = 0;
+  int exc_cont = 0;
   int manise80;
   int other_flg;
   int one_point=0;
   int two_point=0;
   int three_point=0;
   int two_eu_three_dx_points=0;
+  int ssbpoints;
+  int cwpoints;
+  int sc_sidetone;
+  char sc_volume[3] = "";
   /* LZ3NY mods */
 	char contest_name[50];
 	int multiplier_points=-1;
@@ -93,6 +114,7 @@
   int ctcomp = 0;
   int isdupe = 0; //0 if nodupe -- for auto qso b4 (LZ3NY)
   int nob4 = 0;   // allow auto b4
+  int noautocq = 0;
   int emptydir = 0;
   int verbose = 0;
 
@@ -110,6 +132,7 @@
 
   char tlfversion[80] = "";
   char multiplierlist[40]="";
+  char exchange_list[40] = "";
   int timeoffset=0;
   int multi = 0;                /* 0 = SO , 1 = MOST, 2 = MM */
   int trxmode = CWMODE;
@@ -134,11 +157,12 @@
   char buffer[162];
   char call[20];
   char logfile[120] = "general.log";
+  char synclogfile[120];
   char markerfile[120] = "";
   int xplanet = 0;
   char message[25][80] = {"TEST %\n","@ DE %\n","@ [\n","TU 73\n"," @\n","%\n","@ SRI QSO B4 GL\n","AGN\n",
   						" ?\n"," QRZ?\n"," PSE K\n","TEST % %\n","@ [\n","TU %\n","","","","","","","","","","",""};
-  char ph_message[14][40] = {"","","","","","","","","","","",""}; 		// voice keyer file names
+  char ph_message[14][80] = {"","","","","","","","","","","",""}; 		// voice keyer file names
   char hiscall[20];
   char lastcall[20];
   char lastcomment[40];
@@ -172,29 +196,32 @@
   int block_part=0;
   char para_word[80] ="LODNCFS:3C\n"; /* longcw, cluster, search,  DE, contest, filter,  speed,  delay */
   char lastmsg[1000]="";
+  int scale_values[20] = {40,38,36,34,32,30,28,26,24,22,20,18,16,14,12,10,8,6,4,2};
+	char sc_device[40] = "/dev/dsp";
 /*-------------------------------------keyer------------------------------*/
   int keyerport = NO_KEYER;
   int speed = 10;
   int txdelay = 0;
   int weight = 0;
-  char weightbuf[3];
+  char weightbuf[4];
   char speedstr[50] = CW_SPEEDS;
   char tonestr[5]  = "600";
-  int cqdelay = 3;
+  int cqdelay = 8;
   char wkeyerbuffer[400];
   int keyspeed = 5;
   int cfd;  				/* cwkeyer file descriptor */
   int data_ready = 0;
-	char keyer_device[10]= "";	// ttyS0, ttyS1, lp0-2
-	char portaddress[10]= "";	// port address (0x378 etc)
+  char keyer_device[10]= "";	// ttyS0, ttyS1, lp0-2
 	int k_tune;
 	int k_pin14;
 	int k_ptt;
+char controllerport[80] = "/dev/ttyS0";
+int miniterm = 0;
 
 /*-------------------------------------packet-------------------------------*/
-  char spot_ptr[100][82];
-  int spotarray[100];
-  char spotinfo[32][82];
+  char spot_ptr[MAX_SPOTS][82];
+  int spotarray[MAX_SPOTS];
+  char spotinfo[MAX_SPOTS][82];
   int ptr;
   int spot_rdr;
   long int *wwv_ptr;
@@ -202,8 +229,11 @@
   int fdSertnc=0;
   int fdFIFO=0;
   int tncport=1;
+  char tncportname[40];
+  char rigconf[80];
   int in_packetclient;
   int tnc_serial_rate = 2400;
+  char clusterlogin[80]= "";
 
 
 /*-------------------------------------rigctl-------------------------------*/
@@ -217,10 +247,16 @@
 	vfo_t vfo;			/* vfo selection */
 	port_t myport;
 #else
+	float rigfreq;		/* input frequency  */
 	int outfreq;             /* output  to rig */
 #endif
 	int serial_rate = 2400;
 	int rig_port=0;
+	char rigportname[40];
+	int native_rig_fd = 0;
+	int rignumber = 0;
+	int rig_comm_error = 0;
+	int rig_comm_success = 0;
 /*---------------------------------simulator-------------------------------*/
 
    int simulator = 0;
@@ -239,7 +275,7 @@
   char zonearray[MAX_DBLINES][3];
   char ituarray[MAX_DBLINES][3];
   int dataindex[MAX_DBLINES];      /*  index to  datalines */
-  char callarray[MAX_CALLS][12];       /*  internal log representation for duping  */
+  char callarray[MAX_CALLS][20];       /*  internal log representation for duping  */
   char call_exchange[MAX_CALLS][12];
   int  call_band[MAX_CALLS];
   int call_country[MAX_CALLS];
@@ -255,7 +291,10 @@
   char callmaster_result[50][9];
   int max_callmastercalls;
   int callareas[20];
-  int multscore[6];
+  int multscore[NBANDS];
+
+  struct ie_list *main_ie_list;
+
   int multarray_nr = 0;
   int wysiwygmults = 0;
   int callarray_nr =  0;
@@ -265,6 +304,7 @@
   int addzone = 0;                   /* flag for new zone */
   int addcty = 0;                    /* flag for new country */
   int shownewmult = -1;
+  int minute_timer = 0;
 
   int bandinx = 2;  /* 40m */
   int qsonum = 1;
@@ -280,11 +320,11 @@
 	struct tm *time_ptr;
 
 
-  char logline0[81] = "";
-  char logline1[81] = "";
-  char logline2[81] = "";
-  char logline3[81] = "";
-  char logline4[240] = "";
+//  char logline0[81] = "";
+//  char logline1[81] = "";
+//  char logline2[81] = "";
+//  char logline3[81] = "";
+//  char logline4[240] = "";
   char qrg_string[8];
   float freq;
   float mem;
@@ -325,7 +365,9 @@
   int this_second;
   int stop_backgrnd_process = 1;      /* dont start until we know what we are doing */
 
-
+  int wazmult=0; /* to add the abiliti of WAZ zones to be multiplier */
+  int itumult=0; /* to add the abiliti of ITU zones to be multiplier */
+  char itustr[3];
 /* ------------------------------------------------------------------------*/
 /*     Main loop of the program			                           */
 /* ------------------------------------------------------------------------*/
@@ -342,6 +384,14 @@ int main(int argc, char *argv[])
 while ((argc > 1) && (argv[1][0] == '-')) {
 	switch (argv[1][1]) {
 		/* verbose option */
+		case 'f':
+			if (strlen(argv[1]+2) > 0)
+				strcpy (config_file, argv[1]+2);
+			break;
+		case 's':
+			if (strlen(argv[1]+2) > 0)
+				strcpy (synclogfile, argv[1]+2);
+			break;
 		case 'd':				// debug rigctl
 			debugflag = 1;
 			break;
@@ -355,16 +405,13 @@ while ((argc > 1) && (argv[1][0] == '-')) {
 		case 'n':				// output version
 			nopacket = 1;
 			break;
-		case 'x':
-			use_rxvt = 1;
-			break;
 		default:
 			printf("Use: tlf [-v] Verbose\n");
 			printf("         [-V] Version\n");
+			printf("         [-f] Configuration file\n");
 			printf("         [-d] Debug mode\n");
 			printf("         [-h] This message\n");
-			printf("         [-n] Start without packet\n");
-			printf("         [-x] Use rxvt colours\n");
+			printf("         [-n] Start without cluster hookup\n");
 			exit(0);
 			break;
 	}
@@ -392,17 +439,30 @@ strcat (terminal4,  backgrnd_str);
 termbuf[0] = '\0';
 hiscall[0] = '\0';
 
-
+/* getting users terminal string and (if RXVT) setting rxvt colours on it */
+/* LZ3NY hack :) */
+  if (strcasecmp(getenv("TERM"),"rxvt")==0)
+  {
+    use_rxvt=1;
+    printf("terminal is:%s",getenv("TERM"));
+  }
+	else if (strcasecmp(getenv("TERM"), "xterm") == 0)
+  {
+  	use_xterm=1;
+	use_rxvt=1;
+  } else
+    putenv("TERM=rxvt"); /*or going to native console linux driver */
 
 
 if ((mainscreen = newterm(NULL, stdout, stdin)) == NULL){         /* activate ncurses terminal control */
  		perror("initscr");
-		printf("\n Sorry, wrong terminal type !!!!! Try a  linux text terminal or a rxvt!!!" );
+		printf("\n Sorry, wrong terminal type !!!!! \nTry a  linux text terminal or set TERM=linux !!!" );
 		sleep(5);
 
  		exit(EXIT_FAILURE);
  	}
 
+//keypad(stdscr,TRUE);
 
 getmaxyx(stdscr, ymax, xmax);
 noecho();
@@ -418,125 +478,165 @@ refresh();
  		if (start_color() == ERR){
  			perror("start_color");
  			endwin();
-			printf("\n Sorry, wrong terminal type !!!!! \nTry a linux text terminal or rxvt!!!" );
+			printf("\n Sorry, wrong terminal type !!!!! \n\nTry a linux text terminal or set TERM=linux !!!" );
 			sleep(5);
 	 		exit(EXIT_FAILURE);
 	 		}
-    // use linux console colours
-		init_pair(COLOR_BLACK, COLOR_BLACK, COLOR_WHITE);
-	 	init_pair(COLOR_GREEN, COLOR_GREEN, COLOR_YELLOW);
-	 	init_pair(COLOR_RED, COLOR_WHITE, COLOR_RED);
-	 	init_pair(COLOR_CYAN, COLOR_CYAN, COLOR_WHITE);
-	 	init_pair(COLOR_WHITE, COLOR_WHITE, COLOR_BLACK);
-	 	init_pair(COLOR_MAGENTA, COLOR_MAGENTA, COLOR_WHITE);
-	 	init_pair(COLOR_BLUE, COLOR_BLUE, COLOR_YELLOW);
-	 	init_pair(COLOR_YELLOW, COLOR_CYAN, COLOR_YELLOW);
-
+	// use linux console colours
+		init_pair(COLOR_BLACK, tlfcolors[0][0], tlfcolors[0][1]);
+		init_pair(COLOR_GREEN, tlfcolors[1][0], tlfcolors[1][1]);
+		init_pair(COLOR_RED, tlfcolors[2][0], tlfcolors[2][1]);
+		init_pair(COLOR_CYAN, tlfcolors[3][0], tlfcolors[3][1]);
+		init_pair(COLOR_WHITE, tlfcolors[4][0], tlfcolors[4][1]);
+		init_pair(COLOR_MAGENTA, tlfcolors[5][0], tlfcolors[5][1]);
+		init_pair(COLOR_BLUE, tlfcolors[6][0], tlfcolors[6][1]);
+		init_pair(COLOR_YELLOW, tlfcolors[7][0], tlfcolors[7][1]);
 
 		strcpy(tlfversion, "        Welcome to tlf-");
 		strcat(tlfversion, VERSION);
-		strcat(tlfversion, " by PA0RCT!!");
-		mvprintw(0, 0, tlfversion);
-
-
-		refresh();
-
- mvprintw(3,0, "reading country data");
- refresh();
+		strcat(tlfversion, " by PA0R!!");
+		showmsg(tlfversion);
+		showmsg("");
 
+		showmsg("reading country data");
 		readctydata();          /* read ctydb.dat */
+		
+		showmsg("reading configuration data");
 
- mvprintw(4,0, "reading configuration data");
- refresh();
 
 
 		read_logcfg();          /* read the configuration file */
+		read_rules();          /* read the additional contest rules in "rules/contestname"  LZ3NY */
+
+		checklogfile();         /* make sure logfile is there */
+
+//		if (strlen(synclogfile) > 0)
+//			synclog(synclogfile);
+
+        
+		if (strlen(call)==0)  {
+			showmsg("WARNING: No callsign defined in logcfg.dat! exiting...\n\n\n");
+			exit(1);
+		}
 
 if (use_rxvt == 1) {                                  // use rxvt colours
 			init_pair(COLOR_BLACK, COLOR_BLACK, COLOR_RED);
+	if(use_xterm == 1) {
+	 		init_pair(COLOR_GREEN, COLOR_GREEN, COLOR_BLUE);
+	 		init_pair(COLOR_RED, COLOR_WHITE, 8);
+	 		init_pair(COLOR_CYAN, COLOR_CYAN, COLOR_MAGENTA);
+	}else {
 	 		init_pair(COLOR_GREEN, COLOR_GREEN, COLOR_YELLOW);
 	 		init_pair(COLOR_RED, COLOR_WHITE, COLOR_RED);
 	 		init_pair(COLOR_CYAN, COLOR_CYAN, COLOR_RED);
+	}
 	 		init_pair(COLOR_WHITE, COLOR_WHITE, COLOR_BLACK);
+	if(use_xterm == 1) {
+			init_pair(COLOR_MAGENTA, COLOR_MAGENTA, COLOR_WHITE);
+	 		init_pair(COLOR_BLUE, COLOR_BLUE, COLOR_WHITE);
+	}else {
 			init_pair(COLOR_MAGENTA, COLOR_MAGENTA, COLOR_RED);
 	 		init_pair(COLOR_BLUE, COLOR_BLUE, COLOR_YELLOW);
+	}
 	 		init_pair(COLOR_YELLOW, COLOR_CYAN, COLOR_YELLOW);
+} else 
+{
+	// use linux console colours redefined....
+		init_pair(COLOR_BLACK, tlfcolors[0][0], tlfcolors[0][1]);
+		init_pair(COLOR_GREEN, tlfcolors[1][0], tlfcolors[1][1]);
+		init_pair(COLOR_RED, tlfcolors[2][0], tlfcolors[2][1]);
+		init_pair(COLOR_CYAN, tlfcolors[3][0], tlfcolors[3][1]);
+		init_pair(COLOR_WHITE, tlfcolors[4][0], tlfcolors[4][1]);
+		init_pair(COLOR_MAGENTA, tlfcolors[5][0], tlfcolors[5][1]);
+		init_pair(COLOR_BLUE, tlfcolors[6][0], tlfcolors[6][1]);
+		init_pair(COLOR_YELLOW, tlfcolors[7][0], tlfcolors[7][1]);
+
 }
 
 
 if (multlist ==1) {
-	 mvprintw(4,0, "reading multiplier data      ");
- 	refresh();
-
-		max_multipliers = load_multipliers();
+	showmsg("reading multiplier data      ");
+	max_multipliers = load_multipliers();
 
 }
 
   attron(COLOR_PAIR(COLOR_BLACK));
-  mvprintw(5,0, "reading callmaster data");
-  refresh();
+	showmsg("reading callmaster data");
 
   		max_callmastercalls = load_callmaster();
 
+main_ie_list = make_ie_list ();		// get initial exchange file
+if (main_ie_list == NULL)
+	showmsg ("No initial exchange file");
+//else
+//	test_ie_list(main_ie_list);
+
 #ifdef HAVE_LIBHAMLIB                                    // Code for hamlib interface
-mvprintw(8,0, "%s\n", "HAMLIB defined");
-refresh();
+
+	showmsg("HAMLIB defined");
+		
 		if (trx_control  != 0){
+			
+			shownr("Rignumber is", (int) myrig_model);
+			shownr("Rig speed is", serial_rate);
 
-			mvprintw(6,0, "Rig model nr = %d", (int)myrig_model);
-			mvprintw(7,0, "Rig speed = %d", serial_rate) ;
- 			refresh();
+			showmsg("Trying to start rig ctrl");
 
-
-			mvprintw(8,0, "Trying to start rig ctrl");
- 			refresh();
-
-			init_tlf_rig () ;
+			if ((int) myrig_model > 1999)
+				init_native_rig();
+			else
+				init_tlf_rig () ;
 		}
 #else
 		if  (trx_control  != 0) {
-			trx_control = 0;
-			mvprintw(8,0, "No Hamlib library, switching rigcontrol off");
- 			refresh();
+//			trx_control = 0;
+			showmsg("No Hamlib library, using native driver");
+			shownr("Rignumber is", rignumber);
+			shownr("Rig speed is", serial_rate);
+			init_native_rig();
 			sleep(1);
 		}
 #endif                                                   // end code for hamlib interface
 
 		if (keyerport == NET_KEYER)  {
-			mvprintw(9,0, "Keyer = %s", "cwdaemon") ;
- 			refresh();
+			showmsg("Keyer is cwdaemon");
 			if (verbose == 1) sleep(1);
 		 }
+		 if (keyerport == MFJ1278_KEYER) {
+			init_controller();
+		 }
 
 		if(lan_active == 1) {
 			retval = lanrecv_init();
 
 			if (retval < 0)         /* set up the network */
-			 	mvprintw(10,0, "LAN receive  init failed, %d",retval) ;
+				shownr("LAN receive  init failed", retval);
 			else
-			 	mvprintw(10,0, "LAN receive  initialized") ;
+				showmsg("LAN receive  initialized");
 
 			if (lan_send_init() < 0)
-				mvprintw(11,0, "LAN send init failed");
+				showmsg("LAN send init failed");
 			else
-				mvprintw(11,0, "LAN send initialized");
-
-      			refresh();
+				showmsg("LAN send initialized");
 		}
-		if (verbose == 1) sleep(5);
+		if (verbose == 1) sleep(1);
 
 		checkparameters() ;    /* check .paras file */
 
 		clear();
 		strcpy(tlfversion, "        Welcome to tlf-");
 		strcat(tlfversion, VERSION);
-		strcat(tlfversion, " by PA0RCT!!\n\n");
+		strcat(tlfversion, " by PA0R!!\n\n");
 		mvprintw(0, 0, tlfversion);
 		refresh();
 		getmessages();          /* read .paras file */
 		
 		if (nopacket == 1) packetinterface = 0;
 
+		set_term(mainscreen);
+
+		refresh();
+		
 		if (packetinterface != 0){
 
 			if (init_packet() == 0)
@@ -547,9 +647,6 @@ refresh();
 		}
 
 
-		set_term(mainscreen);
-
-		refresh();
 
 		if (keyerport == LPT_KEYER) {    /* open keyer interface if it is there */
 			cfd = open("/dev/cwkeyer0", O_RDWR  );
@@ -577,31 +674,42 @@ refresh();
 							sleep(1);
 
 						}else {
+							netkeyer(K_RESET, "0");
+
 							sprintf(weightbuf, "%d", weight);
 
 							strncpy(keyerbuff, speedstr+(speed * 2), 2);
 							keyerbuff[2] = '\0';
 
+							write_tone();
+
 							netkeyer(K_SPEED, keyerbuff);	// set speed
 
 							netkeyer(K_WEIGHT, weightbuf);	// set weight
-							
+
 							if (strlen(keyer_device) > 0)
 								netkeyer(K_DEVICE, keyer_device); // set device
-								
-							if (strlen(portaddress) > 0)
-								netkeyer(K_ADDRESS, portaddress); // set port address
 
 							sprintf(keyerbuff, "%d", txdelay);
 
 							netkeyer (K_TOD, keyerbuff);		// set TOD
 
+							if (sc_sidetone != 0)			// set soundcard output
+							{
+								netkeyer(K_SIDETONE, "");
+
+								if (strlen(sc_volume) > 0)	// set soundcard volume
+
+									netkeyer (K_STVOLUME, sc_volume);
+
+							}
+
+
 						}
 
-			write_tone();
+				if (keyerport != NET_KEYER) write_tone();
 			}
 
-		checklogfile();         /* make sure logfile is there */
 
 		getwwv();               /* get the latest wwv info from packet */
 
@@ -643,7 +751,7 @@ refresh();
 
 	}else  {
  			printf("Terminal does not support color\n" );
-			printf("Try TERM=rxvt or use a text console !!\n");
+			printf("\nTry TERM=linux  or use a text console !!\n");
  			refresh();
 			sleep(2);
         }
