@@ -23,9 +23,12 @@
 #include "speedup.h"
 #include "speeddown.h"
 #include "set_keyer.h"
-#include "curses.h"
+#include <curses.h>
+#include <string.h>
+#include "startmsg.h"
 #ifdef HAVE_LIBHAMLIB
-#include "rig.h"
+#include <hamlib/rig.h>
+#include <ctype.h>
 #endif
 
 extern int keyerport;
@@ -39,6 +42,7 @@ extern int packetinterface;
 extern int tncport;
 extern int shortqsonr;
 
+int exist_in_multi_list();
 
 char inputbuffer[160];
 FILE *fp;
@@ -47,7 +51,9 @@ int read_logcfg(void){
 
 extern int nodes;
 extern int node;
-extern int multiplier_points; // temp
+extern char config_file[];
+
+char defltconf[80];
 
 	contest=0;
 	speed = 14;
@@ -61,16 +67,28 @@ extern int multiplier_points; // temp
 	nodes=0;
 	node=0;
 	shortqsonr = 0;
+	
+strcpy(defltconf, PACKAGE_DATA_DIR);
+strcat(defltconf, "/logcfg.dat");
 
-if  ( (fp = fopen("logcfg.dat","r"))  == NULL){
+if (strlen(config_file) == 0) strcpy (config_file, "logcfg.dat");
 
-		mvprintw(8,0,  "Error opening logcfg.dat file.\n");
-		refresh();
+if  ( (fp = fopen(config_file,"r"))  == NULL){
+	if ((fp = fopen(defltconf, "r")) == NULL) {
+		showmsg("Error opening logcfg.dat file.");
+		showmsg("Exiting...");
 		sleep(5);
 		endwin();
 		exit(1);
-
 	}
+	else
+	{
+		showstring("Using (Read Only) file", defltconf);
+	}
+
+}else
+	showstring("Opening config file", config_file);
+
 
 	while(!feof(fp)){
 
@@ -80,11 +98,11 @@ if  ( (fp = fopen("logcfg.dat","r"))  == NULL){
 			parse_logcfg(inputbuffer);
 
 
-		}	
+		}
 	}
 
 	fclose(fp);
-	
+
 
 	return(0);
 }
@@ -142,6 +160,11 @@ int parse_logcfg(char *inputbuffer){
 	extern rig_model_t myrig_model;
 #endif
 	extern int rig_port;
+	extern char rigportname[];
+	extern int rignumber;
+	extern char rigconf[];
+	extern char exchange_list[40];
+	extern char tncportname[];
 	extern int netkeyer_port;
 	extern char netkeyer_hostaddress[] ;
 	extern char bc_hostaddress[MAXNODES][16];
@@ -150,9 +173,6 @@ int parse_logcfg(char *inputbuffer){
 	extern char nodes;
 	extern int node;
 	extern int cqwwm2;
-	extern int pfxmult;
-	extern int exc_cont;
-	extern int wpx;
 	extern int landebug;
 	extern int call_update;
 	extern int timeoffset;
@@ -164,16 +184,29 @@ int parse_logcfg(char *inputbuffer){
 	extern int serial_section_mult;
 	extern int sectn_mult;
 	extern int dx_arrlsections;
+	extern int pfxmult;
+ 	extern int exc_cont;
+ 	extern int wpx;
 	extern char markerfile[];
 	extern int xplanet;
 	extern int nob4;
+	extern int noautocq;
 	extern int show_time;
 	extern char keyer_device[];
-	extern char portaddress[];
 	extern int use_vk;
+    extern int wazmult;
+    extern int itumult;
+    extern int cqdelay;
+	extern int trxmode;
+	extern int use_bandoutput;
+	extern int no_arrows;
+	extern int bandindexarray[];
+	extern int ssbpoints;
+	extern int cwpoints;
+	extern int sc_sidetone;
+	extern char sc_volume[];
 
 /* LZ3NY mods */
-char contest_name[50];
 extern int mult_side;
 extern int multiplier_points;
 extern int my_country_points;
@@ -193,6 +226,12 @@ extern int mult_side;
 extern char mit_multiplier_list[][6];
 char *mit_mult_array;
 /* end LZ3NY mods */
+extern int tlfcolors[8][2];
+extern char synclogfile[];
+extern int scale_values[];
+extern char sc_device[40];
+extern char controllerport[80];		// port for multi-mode controller
+extern char clusterlogin[];
 
 
 
@@ -217,7 +256,7 @@ char *mit_mult_array;
 		"CONTEST=",
 		"LOGFILE=",
 		"KEYER_DEVICE=",
-		"PORTADDRESS=",                 /* 20 */
+		"BANDOUTPUT",                 /* 20 */
 		"RECALL_MULTS",
 		"ONE_POINT",
 		"THREE_POINTS",
@@ -235,7 +274,7 @@ char *mit_mult_array;
 		"CHECKWINDOW",					/* 35 */
 		"FILTER",
 		"SEND_DE",
-		"SPEED",
+		"CWSPEED",
 		"TONE",
 		"WEIGHT",                           /* 40 */
 		"TXDELAY",
@@ -315,21 +354,49 @@ char *mit_mult_array;
 		"VKM12=",
 		"VKSPR=",			/* 115 */
 		"VKCWR=",
-		"PFX_MULT",
-		"CONTINENT_EXCHANGE"
+		"WAZMULT",
+		"ITUMULT",
+		"CQDELAY=",
+		"PFX_MULT",			/* 120 */
+ 		"CONTINENT_EXCHANGE",
+		"RULES=",
+		"NOAUTOCQ",
+		"SSBMODE",
+		"NO_BANDSWITCH_ARROWKEYS",  /* 125 */
+		"RIGCONF",
+		"TLFCOLOR1=",
+		"TLFCOLOR2=",
+		"TLFCOLOR3=",
+		"TLFCOLOR4=",			/* 130 */
+		"TLFCOLOR5=",
+		"TLFCOLOR6=",
+		"SYNCFILE=",
+		"SSBPOINTS=",
+		"CWPOINTS=",			/* 135 */
+		"SOUNDCARD",
+		"SIDETONE_VOLUME=",
+		"S_METER=",
+		"SC_DEVICE=",
+		"MFJ1278_KEYER=", 		/* 140 */
+		"CLUSTERLOGIN=",
+		"ORION_KEYER",
+		"INITIAL_EXCHANGE="
 	};
 
-	char teststring[30];
-	char buff[16];
+	char teststring[80];
+	char buff[40];
 	char outputbuff[80];
 	int  ii, enable;
-	char *i, *j;
+	char *i;
+	char *j;
+	int jj, hh;
+	char *tk_ptr;
 
 
 	for (ii = 0; ii <= MAX_COMMANDS; ii++) {
 
 		teststring[0] = '\0';
-		strcat(teststring, commands[ii]);
+		strncat(teststring, commands[ii], 79);
 
 		i = strstr(inputbuffer, teststring);
 
@@ -364,12 +431,17 @@ char *mit_mult_array;
 				break;                                              /* end messages */
 			}
 			case 16  : {
-				strcpy(call, inputbuffer + 5);
+				if (strlen(inputbuffer) > 6)  strcpy(call, inputbuffer + 5);
+                else { mvprintw(6,0,"WARNING: No callsign defined in logcfg.dat! exiting...\n"); refresh();exit(1);}
 				break;
 			}
 			case 17 : {
 				strcpy(whichcontest, inputbuffer + 8);
 				whichcontest[strlen(whichcontest)-1] = '\0';
+                if (strlen(whichcontest)>40) {
+					showmsg("WARNING: contest name is too long! exiting...");
+					exit(1);
+				}
 				setcontest();
 				break;
 			}
@@ -386,12 +458,23 @@ char *mit_mult_array;
 				keyer_device[strlen(keyer_device)-1] = '\0';
 				break;
 			}
-			case 20 : {
-				portaddress[0]='\0';
-				strncat(portaddress, inputbuffer + 12, 9);
-				portaddress[strlen(portaddress)-1] = '\0';
-				break;
-			}
+ 			case 20: {	// Use the bandswitch output on parport0
+ 				use_bandoutput = 1;
+				if (strlen(inputbuffer) > 12)
+				{
+					for (jj = 0; jj <= 9; jj++)  // 10x
+					{
+						hh = ((int) (inputbuffer[jj+10])) - 48;
+						
+						if (hh >= 0 && hh <= 9)
+							bandindexarray[jj] = hh;
+						else
+							bandindexarray[jj] = 0;
+
+					}
+				}
+ 				break;
+ 			}
 			case 21 : {
 				recall_mult = 1;
 				break;
@@ -464,7 +547,7 @@ char *mit_mult_array;
 			}
 			case 38 : {
 				buff[0] = '\0';
-				strncat(buff, inputbuffer + 6, 2);
+				strncat(buff, inputbuffer + 8, 2);
 				speed = speed_conversion(atoi(buff));
 				break;
 			}
@@ -482,8 +565,8 @@ char *mit_mult_array;
 				strcat(buff, inputbuffer + 7);
 				weight = atoi(buff);
 				set_weight(weight);
-				if (weight < -5) weight = -5;
-				if (weight > 5) weight = 5;
+				if (weight < -50) weight = -50;
+				if (weight > 50) weight = 50;
 				break;
 			}
 			case 41 : {
@@ -520,6 +603,10 @@ char *mit_mult_array;
 			case 45 : {
 				buff[0] = '\0';
 				strcat(buff, inputbuffer + 4);
+				if ((strncmp(buff,"MC",2)==0)||(strncmp(buff,"mc",2)==0))  {
+					editor = EDITOR_MC;
+					break;
+				}
 
 				j = strstr(inputbuffer, "joe");
 				if (j != NULL){
@@ -581,7 +668,7 @@ char *mit_mult_array;
 					break;
 			}
 			case 57 : {
-				strncpy(pr_hostaddress, inputbuffer + 11,16);
+				strncpy(pr_hostaddress, inputbuffer + 11,47);
 				pr_hostaddress[strlen(pr_hostaddress)-1] = '\0';
 				break;
 			}
@@ -594,8 +681,12 @@ char *mit_mult_array;
 			}
 			case 59: {
 				buff[0] = '\0';
-				strncat(buff, inputbuffer + 8,1);
-				tncport = atoi(buff)+1;
+				strcat(buff, inputbuffer + 8);
+				if (strlen(buff) > 2) {
+					strncpy(tncportname, buff, 39);
+				} else
+					tncport = atoi(buff)+1;
+				
 				packetinterface=TNC_INTERFACE;
 				break;
 			}
@@ -606,9 +697,15 @@ char *mit_mult_array;
 			case 61 : {
 				buff[0] = '\0';
 				strcat(buff, inputbuffer + 9);
+
+				if (strncmp(buff, "ORION", 5) == 0)
+					rignumber = 2000;
+				else
+					rignumber = atoi(buff);
 #ifdef HAVE_LIBHAMLIB
-				myrig_model = atoi(buff);
+					myrig_model = (rig_model_t) rignumber;
 #endif
+
 				break;
 			}
 			case 62 : {
@@ -626,7 +723,12 @@ char *mit_mult_array;
 			case 64 : {
 				buff[0] = '\0';
 				strcat(buff, inputbuffer + 8);
-				rig_port = atoi(buff);
+				if (buff[0] == '0' || buff[0] == '1') {
+					rig_port = atoi(buff);
+				}
+				else {
+					strncpy(rigportname, buff, 39);
+				}
 				break;
 			}
 			case 65 : {
@@ -689,7 +791,7 @@ char *mit_mult_array;
 				break;
 			}
 			case 86 : {
-					two_point = 1;
+				two_point = 1;
 				universal = 1;
 				break;
 			}
@@ -714,7 +816,7 @@ char *mit_mult_array;
 					strcat(outputbuff, inputbuffer);
 
 				if (strlen(outputbuff) > 8){
-					strncpy(markerfile, outputbuff+8, strlen(outputbuff)-8);
+					strncpy(markerfile, outputbuff+8, strlen(outputbuff)-9);
 					xplanet=1;
 				}
 				break;
@@ -808,8 +910,6 @@ char *mit_mult_array;
 				mit_multlist[0]='\0';
 				multiplier_list[0]='\0';
 				mit_mult_buf[0]='\0';
-//				multlist = 1;
-//				universal = 1;
 				setcontest();
 				break;
 			}
@@ -854,7 +954,7 @@ char *mit_mult_array;
 				break;
 			}
 			case 103 ... 111: {	// get phone messages
-				strncpy (ph_message[ii-103], inputbuffer+5, 39);
+				strncpy (ph_message[ii-103], inputbuffer+5, 70);
 				ph_message[ii-103][strlen(ph_message[ii-103]) -1] = '\0';
 				if (strlen(ph_message[ii-103]) > 0)
 					use_vk = 1;
@@ -867,13 +967,173 @@ char *mit_mult_array;
 					use_vk = 1;
 				break;
 			}
-			case 117: {	// wpx style prefixes mult
-				pfxmult = 1;	// enable set points
-				wpx = 1;		// handle like wpx
+			case 117: {	// WAZ Zone is a Multiplier
+				wazmult=1;
 				break;
 			}
-			case 118: {	// exchange continent abbrev
-				exc_cont = 1;
+			case 118: {	// ITU Zone is a Multiplier
+				itumult = 1;
+				break;
+			}
+			case 119: {	// CQ Delay (sec)
+				char buff[4];
+				if (strlen(inputbuffer)>=9) cqdelay = atoi(strncpy(buff,inputbuffer+8,3));
+                if ((cqdelay<3)||(cqdelay>=120)) cqdelay=8;
+				break;
+			}
+ 			case 120: {	// wpx style prefixes mult
+ 				pfxmult = 1;	// enable set points
+ 				wpx = 1;		// handle like wpx
+ 				break;
+ 			}
+ 			case 121: {	// exchange continent abbrev
+ 				exc_cont = 1;
+ 				break;
+ 			}
+			case 122: {
+				strcpy(whichcontest, inputbuffer + 6);		// RULES=
+				whichcontest[strlen(whichcontest)-1] = '\0';
+                if (strlen(whichcontest)>40) {
+					showmsg("WARNING: contest name is too long! exiting...");
+					sleep(5);
+					exit(1);
+				}
+				setcontest();
+				break;
+			}
+ 			case 123: {	// don't use auto_cq
+ 				noautocq = 1;
+ 				break;
+ 			}
+ 			case 124: {	// start in SSB mode
+ 				trxmode = SSBMODE;
+ 				break;
+ 			}
+ 			case 125: {	// arrow keys don't switch bands...
+ 				no_arrows = 1;
+ 				break;
+ 			}
+ 			case 126: {	// Hamlib rig conf parameters
+    			if (strlen(inputbuffer+8)>=80)
+				{
+					showmsg("WARNING: rigconf parameters too long! exiting...");
+					sleep(5);
+					exit(1);
+				}
+				strncpy(rigconf, inputbuffer + 8, 79);		// RIGCONF=
+				rigconf[strlen(rigconf)-1] = '\0';	// chop LF
+ 				break;
+ 			}
+			case 127: {   // define color GREEN (header)
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[1][0] = inputbuffer[10] - 48;
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[1][1] = inputbuffer[11] - 48;
+			break;
+			}
+			case 128: {   // define color CYAN (windows)
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[3][0] = inputbuffer[10] - 48;
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[3][1] = inputbuffer[11] - 48;
+			break;
+			}
+			case 129: {   // define color WHITE (log window)
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[4][0] = inputbuffer[10] - 48;
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[4][1] = inputbuffer[11] - 48;
+			break;
+			}
+			case 130: {   // define color MAGENTA (Marker / dupes)
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[5][0] = inputbuffer[10] - 48;
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[5][1] = inputbuffer[11] - 48;
+			break;
+			}
+			case 131: {   // define color BLUE (input fields)
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[6][0] = inputbuffer[10] - 48;
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[6][1] = inputbuffer[11] - 48;
+			break;
+			}
+			case 132: {   // define color YELLOW (window frames)
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[7][0] = inputbuffer[10] - 48;
+				if (inputbuffer[10] >= 48 && inputbuffer[10] <= 57)
+					tlfcolors[7][1] = inputbuffer[11] - 48;
+			break;
+			}
+			case 133 : {	// define name of synclogfile
+				synclogfile[0] = '\0';
+				strcat(synclogfile, inputbuffer + 9);
+				synclogfile[strlen(synclogfile)-1] = '\0';
+				break;
+			}
+			case 134: {//SSBPOINTS=
+				buff[0] = '\0';
+				strcat(buff, inputbuffer + 10);
+				ssbpoints = atoi(buff);
+			break;
+			}
+			case 135: {//CWPOINTS=
+				buff[0] = '\0';
+				strcat(buff, inputbuffer + 9);
+				cwpoints = atoi(buff);
+			break;
+			}
+			case 136: {	// SOUNDCARD, use soundcard for cw sidetone
+				sc_sidetone = 1;
+			break;
+			}
+			case 137: {  // sound card volume (default = 70)
+				buff[0] = '\0';
+				strncat(buff, inputbuffer + 16, 2);
+				if (atoi(buff) > 0 && atoi(buff) < 100)
+					strcpy(sc_volume, buff);
+				else
+					strcpy(sc_volume, "70");
+			break;
+			}
+			case 138: {
+				int i = 0;
+
+				tk_ptr=strtok (inputbuffer + 8, ":,.-_\t ");
+
+				if (tk_ptr != NULL) {
+					while(tk_ptr) {
+						if (i < 20) scale_values[i] = atoi (tk_ptr);
+						tk_ptr=strtok(NULL,":,.-_\t ");
+						i++;
+					}
+				}
+
+				break;
+			}
+			case 139: {		// dsp for s-meter
+				strncpy(sc_device, inputbuffer + 10, sizeof (sc_device) -1 );
+				sc_device[strlen(sc_device)-1] = '\0';
+				break;
+			}
+			case 140 : {
+				keyerport = MFJ1278_KEYER;
+				strncpy(controllerport, inputbuffer + 14, sizeof (controllerport) -1 );
+				controllerport[strlen(controllerport)-1] = '\0';
+				break;
+			}
+			case 141 : {
+				strcpy(clusterlogin, inputbuffer + 13 );
+				break;
+			}
+			case 142 : {
+				keyerport = ORION_KEYER;
+				break;
+			}
+			case 143 : {
+				strncpy(exchange_list, inputbuffer + 17, sizeof (exchange_list) -1 );
+				exchange_list[strlen(exchange_list)-1] = '\0';
 				break;
 			}
 
