@@ -20,23 +20,12 @@
 *    scroll  the loglines of the keyer terminal 1 up
 *
 ---------------------------------------------------------------------------*/
+#include "globalvars.h"
 #include "scroll_log.h"
 
 void scroll_log(void)
 {
 
-extern char logline0[81];
-extern char logline1[81];
-extern char logline2[81];
-extern char logline3[81];
-extern char logline4[];
-extern char logfile[];
-extern char qsonrstr[];
-extern int qsonum;
-extern int lan_active;
-extern int exchange_serial;
-extern int highqsonr;
-extern int lan_mutex;
 
 char inputbuffer[800];
 static int ii, kk, mm;
@@ -143,8 +132,11 @@ if  ( (fp = fopen(logfile,"r"))  == NULL){
 		}
 	} else qsonum = atoi(qsonrstr);
 
-		qsonum++;
+		if (logline4[0] != ';') 
+			qsonum++;
+
 //		if((qsonum > highqsonr) && (lan_mutex == 2)) highqsonr++;
+		
 		qsonr_to_str();
 
 }
