@@ -42,6 +42,13 @@ void sendspcall(void){
 		strcat(buffer, call);
 		sendbuf();
 
+	} else if (trxmode == DIGIMODE) {
+
+		strcat (buffer, "{ ");
+		strcat (buffer, call);
+		strcat (buffer, "}");
+		sendbuf();
+
 	} else
 	
 		play_file(ph_message[5]);
