@@ -25,6 +25,8 @@
 #define VERSIONSPLIT "V1.4.1 5/18/96 - N2RJT"
 
 #include "splitscreen.h"
+#include "get_time.h"
+
 
 int currow;
 int curcol;
@@ -54,7 +56,6 @@ extern int ptr;
 
 int len;
 
-
 	for (len = 0; len < strlen(s); len += 80)    {
 
 		strncpy(spot_ptr[ptr], s+len, 80);
@@ -544,16 +545,31 @@ extern int use_rxvt;
 extern WINDOW *sclwin;
 extern int in_packetclient;
 extern int lan_active;
+extern char call[];
+extern char hiscall[];
+extern struct tm *time_ptr;
+extern char talkarray[5][62] ;
+
+
 char lan_out[256];
 static char convers_calls[50][6];
 static int ci, cl = 0, cc;
+static char spotline[160];
+static int  m =0, t = 0;
+static char dxtext[160];
+static char spottime[40];
+static float freq;
+static char *spotpointer;
 
     int i,l;
     l = strlen(tln_input_buffer);
-    if (view_state == STATE_EDITING){
+    if (view_state == STATE_EDITING)
+	{
 		
-		if (s[0] == '<' && s[1] != '<') {				// must be convers
-			for (ci = 0; ci <= cl; ci++) {
+		if (s[0] == '<' && s[1] != '<')
+		{				// must be convers
+			for (ci = 0; ci <= cl; ci++)
+			{
 				if (strncmp(convers_calls[ci], s, 5) == 0) break;
 			}
 
@@ -586,27 +602,107 @@ static int ci, cl = 0, cc;
 		
 		wattroff(sclwin, A_BOLD);
 
-	if (in_packetclient == 1)
-		wrefresh(sclwin);
+		if (in_packetclient == 1)
+			wrefresh(sclwin);
     }
-    for (i=0; i<strlen(s); i++) {
+
+// Cluster private spotting interface
+
+			if (strncmp(s, call, strlen(call)-1) == 0
+					&& strlen(s) < 81
+					&& strchr(s, '>') == NULL) {
+
+				mvprintw(24,0, "                                                                                ");
+
+				if ((strlen(s) + strlen(call) +3) < 80){
+					strcpy (dxtext, s + strlen(call) + 3);
+					if (dxtext[strlen(dxtext)-1] == '\n')
+						dxtext[strlen(dxtext)-1] = '\0'; // remove the newline
+					mvprintw(24,0, dxtext);
+					mvprintw(12, 29, hiscall);
+				}
+				refresh();
+
+				spotpointer = strchr(dxtext, ':');
+
+				if (spotpointer != NULL && strncmp(spotpointer, ": DX ", 5) == 0){
+					spotline[0] = '\0';
+					s[0] = '\0';
+					strcat (spotline, "DX de ");
+					strncat (spotline, dxtext , spotpointer - dxtext);
+					strcat (spotline, ":                                ");
+					freq = atof (spotpointer + 5);
+					if (freq > 1800.0 && freq < 30000.0) {
+
+						if (freq >= 100000.0){
+    						sprintf(spotline+16, "%5.1f  " , freq);
+							sprintf(spotline + 26, spotpointer + 14);
+						}
+						else if (freq >= 10000.0){
+    						sprintf(spotline+17, "%5.1f  " , freq);
+							sprintf(spotline + 26, spotpointer + 13);
+						}
+  						else if (freq >= 1000.0) {
+  							sprintf(spotline+18, "%5.1f  " , freq);
+							sprintf (spotline + 26, spotpointer + 12);
+						}
+  						else {
+  							sprintf(spotline+19, "%5.1f  " , freq);
+							sprintf (spotline + 26, spotpointer + 11);
+						}
+
+							for (m=25; m < 38; m++){
+								if (spotline[m] > 96) spotline[m] -= 32;
+							}
+
+						strcat (spotline, "                                           ");
+    					get_time();
+						strftime(spottime, 80, "%H%MZ", time_ptr);
+						strcpy (spotline+70, spottime);
+						spotline[75] = '\0';
+						strcat (spotline, " <<\n");
+   						strcpy (s, spotline);
+					}
+				}
+				else {
+					for (t=0; t <=4; t++) strcpy(talkarray[t], talkarray[t+1]);
+					if (s[strlen(s)-1] == '\n')
+						s[strlen(s)-1] = '\0'; // remove the newline
+					talkarray[4][0]= '\0';
+					strncat (talkarray[4], s + 8, 60);
+
+					if (s[strlen(s) - 1] != '\n')
+						strcat (s, "\n"); // we need to restore newline here...
+
+				}
+
+			}
+// end cluster private spotting interface
+
+	for (i=0; i<strlen(s); i++) {
         if (s[i]=='\n' || i+l+1 >= COLS) {
-            addlog(tln_input_buffer);
+
+			addlog(tln_input_buffer);
 
             if (lan_active == 1 && lanspotflg == 0){
             	if ((strlen(tln_input_buffer) > 0) && (tln_input_buffer[0] > 32) && (tln_input_buffer[0] < 126)){
-            		strncpy (lan_out, tln_input_buffer, 76);
+            		strncpy (lan_out, tln_input_buffer, 78);
             		strcat (lan_out, "\n");
+					if (strlen(s) == 0)
+						tln_input_buffer[0] = '\0';
             		send_lan_message(CLUSTERMSG ,lan_out);
             		lan_out[0]='\0';
             	}
             }
 
+			l = strlen(tln_input_buffer);
             l = -i-1;
         } else {
-            tln_input_buffer[i+l] = s[i];
+            if (s[i] != '\0' ) tln_input_buffer[i+l] = s[i];
         }
-        tln_input_buffer[i+l+1] = '\0';
+
+		tln_input_buffer[i+l+1] = '\0';
+
     }
 }
 
@@ -634,6 +730,7 @@ extern int packetinterface;
 extern int tnc_serial_rate;
 extern int verbose;
 extern int use_rxvt;
+extern char tncportname[];
 
 struct termios termattribs;
 
@@ -707,23 +804,33 @@ if (packetinterface == TELNET_INTERFACE) {
 	socktimeout(30);
 
 } else if (packetinterface == TNC_INTERFACE){
-	if (tncport == 1) {
+	
+	if (strlen (tncportname) > 2) {
+		tncportname[strlen(tncportname)-1] = '\0';	// remove '\n'
+		if ((fdSertnc = open(tncportname, O_RDWR | O_NONBLOCK)) < 0) {
+                		wprintw(sclwin, "open of %s failed!!!\n", tncportname);
+			wrefresh(sclwin);
+			sleep(2);
+   			return(-1);
+		}
+	} else {
+		if (tncport == 1) {
     		if ((fdSertnc = open("/dev/ttyS0", O_RDWR | O_NONBLOCK)) < 0) {
                 		wprintw(sclwin, "open of /dev/ttyS0 failed!!!\n");
-			wrefresh(sclwin);
-			sleep(2);
-                		return(-1);
+				wrefresh(sclwin);
+				sleep(2);
+                return(-1);
     		}
- 	}else if(tncport == 2){
+ 		}else if(tncport == 2){
 
-   		if ((fdSertnc = open("/dev/ttyS1", O_RDWR | O_NONBLOCK)) < 0) {
+   			if ((fdSertnc = open("/dev/ttyS1", O_RDWR | O_NONBLOCK)) < 0) {
                 		wprintw(sclwin, "open of /dev/ttyS1 failed!!!\n");
-			wrefresh(sclwin);
-			sleep(2);
-
-			return(-1);
+				wrefresh(sclwin);
+				sleep(2);
+				return(-1);
     		}
     	}
+	}
 
 	termattribs.c_iflag = IGNBRK | IGNPAR | IMAXBEL | IXOFF;
     	termattribs.c_oflag = 0;
@@ -873,11 +980,13 @@ int packet(){
   extern int fdFIFO;
   extern int packetinterface;
   extern int in_packetclient;
+  extern char clusterlogin[];
 
 char line[BUFFERSIZE];
 
 int i = 0;
 int c, count;
+static int sent_login = 0;
 
   in_packetclient=1;
   sleep(1);
@@ -888,18 +997,36 @@ int c, count;
 
    count=0;
 
-	if ((tln_loglines == 0) && (packetinterface == TELNET_INTERFACE)) addtext ("Welcome to TLF telnet\n\n");
+	if ((tln_loglines == 0) && (packetinterface == TELNET_INTERFACE)) {
+		addtext ("Welcome to TLF telnet\n\n");
+		if ((sent_login == 0) && (strlen(clusterlogin) > 0) && (packetinterface == TELNET_INTERFACE) && (prsock > 0)){
+				usputs(prsock, clusterlogin);
+				sent_login = 1;
+				addtext ("logged into cluster...\n\n");
+				sleep(1);
+				endwin();
+   				set_term(mainscreen);
+   				clear();
+   				clear_display();
+   				in_packetclient=0;
+				return(0);
+		}
+
+	}
 	if ((tln_loglines == 0) && (packetinterface == TNC_INTERFACE)) addtext ("Welcome to TLF tnc terminal\n\n");
 
 
    while(1){
     		wrefresh(entwin);
 
-		while ((c = wgetch(entwin))==-1){
+		while ((c = wgetch(entwin))==-1)
+		{
 
-			 if (packetinterface == TELNET_INTERFACE) {
+			 if (packetinterface == TELNET_INTERFACE)
+			 {
 
-			 	if (prsock > 0) {
+			 	if (prsock > 0)
+				{
 
 					line[0]='\0';
 					i=0;
@@ -907,36 +1034,41 @@ int c, count;
 					i = recvline(&prsock, line, BUFFERSIZE-1);
 
 				}
-				else  {
+				else
+				{
 					wprintw(sclwin, "There is no connection.... going back to tlf !!\n");
 					wrefresh(sclwin);
 					sleep(2);
 					i = -1;
 				}
 
-        				if (i == -1) {
+    			if (i == -1)
+				{
 					cleanup_telnet();
-            				return(-1);
+     				return(-1);
 
 				}
-				else if (i != -2){
-			            	line[i] = '\0';
-           				sanitize(line);
-	       				addtext(line);
-        				}
+				else if (i != -2)
+				{
+			 		line[i] = '\0';
+           			sanitize(line);
+	       			addtext(line);
+    			}
 
 			}
 
-			else if (packetinterface == TNC_INTERFACE){
+			else if (packetinterface == TNC_INTERFACE)
+			{
 
-				if (fdSertnc > 0)  {
+				if (fdSertnc > 0)
+				{
 
 					i = read (fdSertnc, line, BUFFERSIZE-1);
 
 					if ( i > 0) {
 						line[i] = '\0';
-            					sanitize(line);
-            					addtext(line);
+            			sanitize(line);
+            			addtext(line);
 					}
 				}
 			}
@@ -958,6 +1090,14 @@ int c, count;
     		if (edit_line(c)) {
         			gather_input(line);
 
+			if( strcmp(line, ":exit") == 0) {
+				endwin();
+				exit(1);
+			}
+			if( strcmp(line, " :exit") == 0){
+				endwin();
+				exit(1);
+			}
 			if( strcmp(line, ":") == 0)  break;
 			if( strcmp(line, " :") == 0) break;
 
@@ -982,7 +1122,7 @@ int c, count;
         			start_editing();
     		}
 	}
-
+	endwin();
    set_term(mainscreen);
    clear();
    clear_display();
